@@ -1,4 +1,4 @@
-/* $Id: expense.c,v 1.65 2009/01/22 22:09:38 rikster5 Exp $ */
+/* $Id: expense.c,v 1.69 2009/08/28 04:58:48 rikster5 Exp $ */
 
 /*******************************************************************************
  * expense.c
@@ -85,7 +85,7 @@ struct MyExpense {
 };
 
 struct currency_s {
-   char *country;
+   const char *country;
    int currency;
 };
 
@@ -184,7 +184,7 @@ struct MyExpense *glob_myexpense_list=NULL;
 /******************************************************************************/
 /* Prototypes                                                                 */
 /******************************************************************************/
-static void display_records();
+static void display_records(void);
 static void connect_changed_signals(int con_or_dis);
 static void cb_clist_selection(GtkWidget      *clist,
                                gint           row,
@@ -193,7 +193,7 @@ static void cb_clist_selection(GtkWidget      *clist,
                                gpointer       data);
 static void cb_add_new_record(GtkWidget *widget, gpointer data);
 static void cb_pulldown_menu(GtkWidget *item, unsigned int value);
-static int  make_menu(char *items[], int menu_index, GtkWidget **Poption_menu,
+static int  make_menu(const char *items[], int menu_index, GtkWidget **Poption_menu,
                      GtkWidget *menu_items[]);
 static int  expense_find(int unique_id);
 static void cb_category(GtkWidget *item, int selection);
@@ -653,7 +653,7 @@ static void cb_delete(GtkWidget *widget, gpointer data)
  * This is called when the "Clear" button is pressed.
  * It just clears out all the detail fields.
  */
-static void exp_clear_details()
+static void exp_clear_details(void)
 {
    time_t ltime;
    struct tm *now;
@@ -933,7 +933,7 @@ static int display_record(struct MyExpense *mexp, int at_row)
  * This function lists the records in the clist on the left side of
  * the screen.
  */
-static void display_records()
+static void display_records(void)
 {
    int num, i;
    int entries_shown;
@@ -1322,7 +1322,7 @@ static void cb_pulldown_menu(GtkWidget *item, unsigned int value)
  * Just a convenience function for passing in an array of strings and getting
  * them all stuffed into a menu.
  */
-static int make_menu(char *items[], int menu_index, GtkWidget **Poption_menu,
+static int make_menu(const char *items[], int menu_index, GtkWidget **Poption_menu,
                      GtkWidget *menu_items[])
 {
    int i, item_num;
@@ -1363,7 +1363,7 @@ static int make_menu(char *items[], int menu_index, GtkWidget **Poption_menu,
 /* 
  * This function makes all of the menus on the screen.
  */
-static void make_menus()
+static void make_menus(void)
 {
    struct ExpenseAppInfo exp_app_info;
    unsigned char *buf;
@@ -1372,7 +1372,7 @@ static void make_menus()
    long char_set;
    char *cat_name;
 
-   char *payment[MAX_PAYMENTS+1]={
+   const char *payment[MAX_PAYMENTS+1]={
       N_("American Express"),
       N_("Cash"),
       N_("Check"),
@@ -1383,7 +1383,7 @@ static void make_menus()
       N_("Unfiled"),
       NULL
    };
-   char *expense_type[MAX_CURRENCYS+1]={
+   const char *expense_type[MAX_CURRENCYS+1]={
       N_("Airfare"),
       N_("Breakfast"),
       N_("Bus"),
@@ -1414,7 +1414,7 @@ static void make_menus()
       N_("Train"),
       NULL
    };
-   char *currency[MAX_CURRENCYS+1];
+   const char *currency[MAX_CURRENCYS+1];
 
 
    jp_logf(JP_LOG_DEBUG, "Expense: make_menus\n");
@@ -1615,14 +1615,13 @@ int plugin_gui(GtkWidget *vbox, GtkWidget *hbox, unsigned int unique_id)
    gtk_clist_set_column_title(GTK_CLIST(clist), 1, _("Type"));
    gtk_clist_set_column_title(GTK_CLIST(clist), 2, _("Amount"));
 
-   /* TODO: Set auto resize but need a bit more space between columns
+   /* auto resize is used in all the other application clists but here
+    * it produces a cramped layout so a minimum width is specified */
    gtk_clist_set_column_auto_resize(GTK_CLIST(clist), 0, TRUE);
+   gtk_clist_set_column_min_width(GTK_CLIST(clist), 0, 44);
    gtk_clist_set_column_auto_resize(GTK_CLIST(clist), 1, TRUE);
+   gtk_clist_set_column_min_width(GTK_CLIST(clist), 1, 100);
    gtk_clist_set_column_auto_resize(GTK_CLIST(clist), 2, FALSE);
-   */ 
-   gtk_clist_set_column_width(GTK_CLIST(clist), 0, 50);
-   gtk_clist_set_column_width(GTK_CLIST(clist), 1, 140);
-   gtk_clist_set_column_width(GTK_CLIST(clist), 2, 70);
   
    gtk_clist_column_titles_active(GTK_CLIST(clist));
    gtk_signal_connect(GTK_OBJECT(clist), "click_column",
@@ -1631,7 +1630,7 @@ int plugin_gui(GtkWidget *vbox, GtkWidget *hbox, unsigned int unique_id)
    gtk_signal_connect(GTK_OBJECT(clist), "select_row",
                       GTK_SIGNAL_FUNC(cb_clist_selection),
                       NULL);
-   /* gtk_clist_set_shadow_type(GTK_CLIST(clist), SHADOW);*/
+   gtk_clist_set_shadow_type(GTK_CLIST(clist), SHADOW);
    gtk_clist_set_selection_mode(GTK_CLIST(clist), GTK_SELECTION_BROWSE);
 
    /* Restore previous sorting configuration */
@@ -1913,7 +1912,7 @@ int plugin_gui(GtkWidget *vbox, GtkWidget *hbox, unsigned int unique_id)
  * its windows are terminated.  Desirable actions include freeing allocated 
  * memory, storing state variables, etc. 
  */
-int plugin_gui_cleanup() {
+int plugin_gui_cleanup(void) {
    int b;
    
    jp_logf(JP_LOG_DEBUG, "Expense: plugin_gui_cleanup\n");
