@@ -1,4 +1,4 @@
-/* $Id: address.c,v 1.52 2008/05/14 18:05:37 rikster5 Exp $ */
+/* $Id: address.c,v 1.57 2009-09-24 03:58:18 rikster5 Exp $ */
 
 /*******************************************************************************
  * address.c
@@ -20,8 +20,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  ******************************************************************************/
 
+/********************************* Includes ***********************************/
 #include "config.h"
-#include "i18n.h"
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
@@ -30,32 +30,24 @@
 #include <pi-socket.h>
 #include <pi-address.h>
 #include <pi-dlp.h>
+
 #include "address.h"
+#include "i18n.h"
 #include "utils.h"
 #include "log.h"
 #include "prefs.h"
 #include "libplugin.h"
 #include "password.h"
 
-#define ADDRESS_EOF 7
-
-static int glob_sort_rule;
+/********************************* Constants **********************************/
 #define SORT_JAPANESE 8
 #define SORT_JOS 16
+
+/******************************* Global vars **********************************/
+static int glob_sort_rule;
 int addr_sort_order;
 
-#ifdef JPILOT_DEBUG
-void print_address_list(AddressList **al)
-{
-   AddressList *temp_al, *prev_al;
-
-   for (prev_al=NULL, temp_al=*al; temp_al;
-	prev_al=temp_al, temp_al=temp_al->next) {
-      jp_logf(JP_LOG_FILE | JP_LOG_STDOUT, "entry[0]=[%s]\n", temp_al->maddr.addr.entry[0]);
-   }
-}
-#endif
-
+/****************************** Main Code *************************************/
 int address_compare(const void *v1, const void *v2)
 {
    AddressList **al1, **al2;
@@ -247,9 +239,7 @@ int address_compare(const void *v1, const void *v2)
    return 0;
 }
 
-/*
- * sort_order: 0=descending,  1=ascending
- */
+/* sort_order: SORT_ASCENDING | SORT_DESCENDING */
 int address_sort(AddressList **al, int sort_order)
 {
    AddressList *temp_al;
@@ -261,7 +251,7 @@ int address_sort(AddressList **al, int sort_order)
    for (count=0, temp_al=*al; temp_al; temp_al=temp_al->next, count++) {}
 
    if (count<2) {
-      /* We don't have to sort less than 2 items */
+      /* No need to sort 0 or 1 items */
       return EXIT_SUCCESS;
    }
 
@@ -292,7 +282,6 @@ int address_sort(AddressList **al, int sort_order)
       sort_al[i] = temp_al;
    }
 
-   /* qsort them */
    qsort(sort_al, count, sizeof(AddressList *), address_compare);
 
    /* Put the linked list in the order of the array */
@@ -316,68 +305,6 @@ int address_sort(AddressList **al, int sort_order)
    return EXIT_SUCCESS;
 }
 
-int pc_address_write(struct Address *addr, PCRecType rt, unsigned char attrib,
-		     unsigned int *unique_id)
-{
-#ifndef PILOT_LINK_0_12
-   char record[65536];
-   int rec_len;
-#else /* PILOT_LINK_0_12 */
-   pi_buffer_t *RecordBuffer;
-#endif /* PILOT_LINK_0_12 */
-   int i;
-   buf_rec br;
-   long char_set;
-
-   get_pref(PREF_CHAR_SET, &char_set, NULL);
-   if (char_set != CHAR_SET_LATIN1) {
-      for (i = 0; i < 19; i++) {
-	 if (addr->entry[i]) charset_j2p(addr->entry[i], strlen(addr->entry[i])+1, char_set);
-      }
-   }
-
-#ifndef PILOT_LINK_0_12
-   rec_len = pack_Address(addr, (unsigned char *)record, 65535);
-   if (!rec_len) {
-      PRINT_FILE_LINE;
-      jp_logf(JP_LOG_WARN, "pack_Address %s\n", _("error"));
-      return EXIT_FAILURE;
-   }
-#else /* PILOT_LINK_0_12 */
-   RecordBuffer = pi_buffer_new(0);
-   if (pack_Address(addr, RecordBuffer, address_v1) == -1) {
-      PRINT_FILE_LINE;
-      jp_logf(JP_LOG_WARN, "pack_Address %s\n", _("error"));
-      return EXIT_FAILURE;
-   }
-#endif /* PILOT_LINK_0_12 */
-   br.rt=rt;
-   br.attrib = attrib;
-#ifndef PILOT_LINK_0_12
-   br.buf = record;
-   br.size = rec_len;
-#else /* PILOT_LINK_0_12 */
-   br.buf = RecordBuffer->data;
-   br.size = RecordBuffer->used;
-#endif /* PILOT_LINK_0_12 */
-   /* Keep unique ID intact */
-   if (unique_id) {
-      br.unique_id = *unique_id;
-   } else {
-      br.unique_id = 0;
-   }
-
-   jp_pc_write("AddressDB", &br);
-   if (unique_id) {
-      *unique_id = br.unique_id;
-   }
-
-#ifdef PILOT_LINK_0_12
-   pi_buffer_free(RecordBuffer);
-#endif
-   return EXIT_SUCCESS;
-}
-
 void free_AddressList(AddressList **al)
 {
    AddressList *temp_al, *temp_al_next;
@@ -418,7 +345,7 @@ int get_addresses(AddressList **address_list, int sort_order)
    return get_addresses2(address_list, sort_order, 1, 1, 1, CATEGORY_ALL);
 }
 /*
- * sort_order: 0=descending,  1=ascending
+ * sort_order: SORT_ASCENDING | SORT_DESCENDING
  * modified, deleted and private, 0 for no, 1 for yes, 2 for use prefs
  */
 int get_addresses2(AddressList **address_list, int sort_order,
@@ -434,9 +361,7 @@ int get_addresses2(AddressList **address_list, int sort_order,
    long char_set;
    buf_rec *br;
    char *buf;
-#ifdef PILOT_LINK_0_12
    pi_buffer_t *RecordBuffer;
-#endif /* PILOT_LINK_0_12 */
 
    jp_logf(JP_LOG_DEBUG, "get_addresses2()\n");
    if (modified==2) {
@@ -454,6 +379,7 @@ int get_addresses2(AddressList **address_list, int sort_order,
    } else {
       keep_priv = privates;
    }
+   get_pref(PREF_CHAR_SET, &char_set, NULL);
 
    *address_list=NULL;
    recs_returned = 0;
@@ -462,7 +388,7 @@ int get_addresses2(AddressList **address_list, int sort_order,
    if (-1 == num)
      return 0;
 
-   for (i=0, temp_list = records; temp_list; temp_list = temp_list->next, i++) {
+   for (temp_list = records; temp_list; temp_list = temp_list->next) {
       if (temp_list->data) {
 	 br=temp_list->data;
       } else {
@@ -482,44 +408,27 @@ int get_addresses2(AddressList **address_list, int sort_order,
 	 continue;
       }
 
-#ifndef PILOT_LINK_0_12
-      num = unpack_Address(&addr, br->buf, br->size);
-#else /* PILOT_LINK_0_12 */
       RecordBuffer = pi_buffer_new(br->size);
       memcpy(RecordBuffer->data, br->buf, br->size);
       RecordBuffer->used = br->size;
-#endif /* PILOT_LINK_0_12 */
 
-#ifndef PILOT_LINK_0_12
-      if (num <= 0) {
-	 continue;
-      }
-#else /* PILOT_LINK_0_12 */
       if (unpack_Address(&addr, RecordBuffer, address_v1) == -1) {
 	 pi_buffer_free(RecordBuffer);
 	 continue;
       }
       pi_buffer_free(RecordBuffer);
-#endif /* PILOT_LINK_0_12 */
 
       if ( ((br->attrib & 0x0F) != category) && category != CATEGORY_ALL) {
 	 continue;
       }
       buf = NULL;
-      get_pref(PREF_CHAR_SET, &char_set, NULL);
       if (char_set != CHAR_SET_LATIN1) {
 	 for (i = 0; i < 19; i++) {
 	    if ((addr.entry[i] != NULL) && (addr.entry[i][0] != '\0')) {
-               buf = charset_p2newj(addr.entry[i], strlen(addr.entry[i])+1, char_set);
+               buf = charset_p2newj(addr.entry[i], -1, char_set);
                if (buf) {
-		  if (strlen(buf) > strlen(addr.entry[i])) {
-		     free(addr.entry[i]);
-		     addr.entry[i] = strdup(buf);
-		     free(buf);
-		  } else {
-		     multibyte_safe_strncpy(addr.entry[i], buf, strlen(addr.entry[i])+1);
-		     free(buf);
-		  }
+                  free(addr.entry[i]);
+                  addr.entry[i] = buf;
 	       }
 	    }
 	 }
@@ -551,3 +460,59 @@ int get_addresses2(AddressList **address_list, int sort_order,
 
    return recs_returned;
 }
+
+int pc_address_write(struct Address *addr, PCRecType rt, unsigned char attrib,
+		     unsigned int *unique_id)
+{
+   pi_buffer_t *RecordBuffer;
+   int i;
+   buf_rec br;
+   long char_set;
+
+   get_pref(PREF_CHAR_SET, &char_set, NULL);
+   if (char_set != CHAR_SET_LATIN1) {
+      for (i = 0; i < 19; i++) {
+	 if (addr->entry[i]) 
+            charset_j2p(addr->entry[i], strlen(addr->entry[i])+1, char_set);
+      }
+   }
+
+   RecordBuffer = pi_buffer_new(0);
+   if (pack_Address(addr, RecordBuffer, address_v1) == -1) {
+      PRINT_FILE_LINE;
+      jp_logf(JP_LOG_WARN, "pack_Address %s\n", _("error"));
+      return EXIT_FAILURE;
+   }
+   br.rt=rt;
+   br.attrib = attrib;
+   br.buf = RecordBuffer->data;
+   br.size = RecordBuffer->used;
+   /* Keep unique ID intact */
+   if (unique_id) {
+      br.unique_id = *unique_id;
+   } else {
+      br.unique_id = 0;
+   }
+
+   jp_pc_write("AddressDB", &br);
+   if (unique_id) {
+      *unique_id = br.unique_id;
+   }
+
+   pi_buffer_free(RecordBuffer);
+
+   return EXIT_SUCCESS;
+}
+
+#ifdef JPILOT_DEBUG
+void print_address_list(AddressList **al)
+{
+   AddressList *temp_al, *prev_al;
+
+   for (prev_al=NULL, temp_al=*al; temp_al;
+	prev_al=temp_al, temp_al=temp_al->next) {
+      jp_logf(JP_LOG_FILE | JP_LOG_STDOUT, "entry[0]=[%s]\n", temp_al->maddr.addr.entry[0]);
+   }
+}
+#endif
+
