@@ -1,4 +1,4 @@
-/* $Id: address.h,v 1.11 2007-10-23 18:29:14 judd Exp $ */
+/* $Id: address.h,v 1.18 2009-11-08 17:12:10 rousseau Exp $ */
 
 /*******************************************************************************
  * address.h
@@ -26,11 +26,34 @@
 #include <pi-address.h>
 #include "utils.h"
 
-/* This flag affects sorting of address records
- * 0 : by lastname, first
- * 1 : by company name
+/*
+ * This describes how to draw a GUI entry for each field in an address record
  */
-extern int sort_by_company;
+typedef struct {
+   int record_field;
+   int notebook_page;
+   int type;
+} address_schema_entry;
+
+#define NUM_IMS 2
+#define NUM_ADDRESSES 3
+#define NUM_CONTACT_NOTEBOOK_PAGES 6
+#define NUM_ADDRESS_NOTEBOOK_PAGES 4
+#define NUM_ADDRESS_FIELDS 19
+
+#define ADDRESS_GUI_LABEL_TEXT 2 /* Show a label and a textview widget */
+#define ADDRESS_GUI_DIAL_SHOW_PHONE_MENU_TEXT 3 /* Show a dial button, show in list radio button, and a phone menu, and a textview */
+#define ADDRESS_GUI_IM_MENU_TEXT 4 /* Show a IM menu and a textview */
+#define ADDRESS_GUI_ADDR_MENU_TEXT 5 /* Show a address menu and a textview */
+#define ADDRESS_GUI_WEBSITE_TEXT 6 /* Show a website button and a textview */
+#define ADDRESS_GUI_BIRTHDAY 7 /* Show a birthdate checkbox and complex birthday GUI */
+
+#define SORT_BY_LNAME 1
+#define SORT_BY_FNAME 2
+#define SORT_BY_COMPANY 4
+
+/* This flag affects sorting of address records */
+extern int addr_sort_order;
 
 int get_address_app_info(struct AddressAppInfo *aai);
 
@@ -39,14 +62,11 @@ int pc_address_write(struct Address *a, PCRecType rt, unsigned char attrib,
 
 void free_AddressList(AddressList **al);
 
-/* 
- * sort_order: 0=descending,  1=ascending
- */
 int get_addresses(AddressList **address_list, int sort_order);
 int get_addresses2(AddressList **address_list, int sort_order,
 		  int modified, int deleted, int privates, int category);
 
-int address_print();
+int address_print(void);
 int address_import(GtkWidget *window);
 int address_export(GtkWidget *window);
 
