@@ -1,4 +1,4 @@
-/* $Id: alarms.c,v 1.44 2007/12/18 00:41:42 rikster5 Exp $ */
+/* $Id: alarms.c,v 1.50 2009/09/10 06:01:53 rikster5 Exp $ */
 
 /*******************************************************************************
  * alarms.c
@@ -30,6 +30,7 @@
  * remind_time is the time a window is to be popped up (it may be postponed)
  */
 
+/********************************* Includes ***********************************/
 #include "config.h"
 #include <gtk/gtk.h>
 #include <time.h>
@@ -37,14 +38,15 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <pi-datebook.h>
+#include "jp-pi-calendar.h"
 
+#include "i18n.h"
 #include "utils.h"
+#include "datebook.h"
 #include "log.h"
 #include "prefs.h"
-#include "i18n.h"
-#include "datebook.h"
 
+/********************************* Constants **********************************/
 /* This is how often to check for alarms in seconds */
 /* Every call takes CPU time(not much), so you may want it to be greater */
 #define ALARM_INTERVAL 10
@@ -60,6 +62,18 @@
 /* Uncomment for verbose debugging of the alarm code */
 /* #define ALARMS_DEBUG */
 
+/******************************* Global vars **********************************/
+/* main jpilot window */
+extern GtkWidget *window;
+
+static struct jp_alarms *alarm_list=NULL;
+static struct jp_alarms *Plast_alarm_list=NULL;
+static struct jp_alarms *next_alarm=NULL;
+
+static int glob_skip_all_alarms;
+static int total_alarm_windows;
+
+/****************************** Prototypes ************************************/
 typedef enum {
    ALARM_NONE = 0,
    ALARM_NEW,
@@ -84,27 +98,17 @@ struct alarm_dialog_data {
    int button_hit;
 };
 
-/* main jpilot window */
-extern GtkWidget *window;
-
-static struct jp_alarms *alarm_list=NULL;
-static struct jp_alarms *Plast_alarm_list=NULL;
-static struct jp_alarms *next_alarm=NULL;
-
-static int glob_skip_all_alarms;
-static int total_alarm_windows;
-
 void alarms_add_to_list(unsigned int unique_id,
 			AlarmType type,
 			time_t alarm_time,
 			time_t alarm_advance);
 int alarms_find_next(struct tm *date1, struct tm *date2, int soonest_only);
 
+/****************************** Main Code *************************************/
 /* Alarm GUI */
 
 /* Start of Dialog window code */
-static void cb_dialog_button(GtkWidget *widget,
-			     gpointer   data)
+static void cb_dialog_button(GtkWidget *widget, gpointer data)
 {
    struct alarm_dialog_data *Pdata;
    GtkWidget *w;
@@ -172,12 +176,8 @@ int dialog_alarm(char *title, char *reason,
    struct alarm_dialog_data *Pdata;
    long pref_units;
    long pref_entry;
-#ifdef ENABLE_GTK2
    GtkWidget *image;
    char *markup;
-#else
-   char markup[2048];
-#endif
 
    /* Prevent alarms from going crazy and using all resources */
    if (total_alarm_windows > 20) {
@@ -196,9 +196,7 @@ int dialog_alarm(char *title, char *reason,
                       GTK_SIGNAL_FUNC(cb_destroy_dialog), alarm_dialog);
 
    gtk_window_set_transient_for(GTK_WINDOW(alarm_dialog), GTK_WINDOW(window));
-#ifdef ENABLE_GTK2
    gtk_window_stick(GTK_WINDOW(alarm_dialog));
-#endif
 
    vbox1 = gtk_vbox_new(FALSE, 5);
    gtk_container_add(GTK_CONTAINER(alarm_dialog), vbox1);
@@ -206,14 +204,11 @@ int dialog_alarm(char *title, char *reason,
    hbox1 = gtk_hbox_new(FALSE, 5);
    gtk_box_pack_start(GTK_BOX(vbox1), hbox1, FALSE, FALSE, 0);
 
-#ifdef ENABLE_GTK2
    image = gtk_image_new_from_stock(GTK_STOCK_DIALOG_INFO, GTK_ICON_SIZE_DIALOG);
    gtk_box_pack_start(GTK_BOX(hbox1), image, FALSE, FALSE, 12);
-#endif
 
    /* Label */
    label = gtk_label_new("");
-#ifdef ENABLE_GTK2
    if (note_str[0] == '\0') {
       markup = g_markup_printf_escaped("<b><big>%s</big></b>\n\n%s\n\n%s",
                desc_str, reason, time_str);
@@ -223,32 +218,12 @@ int dialog_alarm(char *title, char *reason,
    }
    gtk_label_set_markup(GTK_LABEL(label), markup);
    g_free(markup);
-#else
-   if (note_str[0] == '\0') {
-      g_snprintf(markup, sizeof(markup), "%s\n\n%s\n\n%s",
-                 desc_str, reason, time_str);
-   } else {
-      g_snprintf(markup, sizeof(markup), "%s\n\n%s\n\n%s\n\n%s",
-                 desc_str, reason, time_str, note_str);
-   }
-   gtk_label_set_text(GTK_LABEL(label), markup);
-#endif
    gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
    gtk_box_pack_start(GTK_BOX(hbox1), label, FALSE, FALSE, 6);
 
    /* remind delay */
    hbox1 = gtk_hbox_new(TRUE, 6);
-#ifdef ENABLE_GTK2
    remind_entry = gtk_spin_button_new_with_range(0, 59, 1);
-#else
-   {
-      GtkAdjustment *spinner_adj;
-
-      spinner_adj = (GtkAdjustment *) gtk_adjustment_new(50.0, 0.0, 59.0,
-                                                          1.0, 5.0, 5.0);
-      remind_entry = gtk_spin_button_new(spinner_adj, 1.0, 0);
-   }
-#endif
    gtk_box_pack_start(GTK_BOX(hbox1), remind_entry, FALSE, TRUE, 5);
 
    vbox_temp = gtk_vbox_new(FALSE, 0);
@@ -283,11 +258,7 @@ int dialog_alarm(char *title, char *reason,
 		      GINT_TO_POINTER(DIALOG_SAID_2));
    gtk_box_pack_start(GTK_BOX(hbox1), button, TRUE, TRUE, 1);
 
-#ifdef ENABLE_GTK2
    button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
-#else
-   button = gtk_button_new_with_label(_("OK"));
-#endif
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_dialog_button),
 		      GINT_TO_POINTER(DIALOG_SAID_1));
@@ -442,10 +413,16 @@ void alarms_write_file(void)
 
    time(&ltime);
    now = localtime(&ltime);
-
+   /* Alarm is triggered within ALARM_INTERVAL/2 seconds of the minute.
+    * Potentially need to round timestamp up to the correct minute. */
+   if ((59 - now->tm_sec) <= ALARM_INTERVAL/2) {
+      now->tm_min++;
+      mktime(now);
+   }
+   
    out=jp_open_home_file(EPN".alarms.tmp", "w");
    if (!out) {
-      jp_logf(JP_LOG_WARN, _("Unable to open %s%s file\n"), EPN, ".alarms.tmp");
+      jp_logf(JP_LOG_WARN, _("Unable to open file: %s%s\n"), EPN, ".alarms.tmp");
       return;
    }
    fail=0;
@@ -575,12 +552,12 @@ int alarms_do_one(struct Appointment *appt,
    memset(command, 0, sizeof(command));
    if (do_command) {
       command[0]='\0';
-      for (i=0; i<MAX_PREF_VALUE-1; i++) {
+      for (i=0; i<MAX_PREF_LEN-1; i++) {
 	 c1 = pref_command[i];
 	 c2 = pref_command[i+1];
 	 len = strlen(command);
-	 /* expand '%t' */
 	 if (c1=='%') {
+            /* expand '%t' */
 	    if (c2=='t') {
 	       i++;
 	       strncat(command, time1_str, sizeof(command)-2-len);
@@ -599,6 +576,7 @@ int alarms_do_one(struct Appointment *appt,
 	       strncat(command, desc_str, sizeof(command)-2-len);
 	       continue;
 	    }
+	    /* expand '%N' */
 	    if (c2=='N') {
 	       i++;
 	       strncat(command, note_str, sizeof(command)-2-len);
@@ -641,7 +619,7 @@ gint cb_timer_alarms(gpointer data)
    struct jp_alarms *temp_alarm, *ta_next;
    AppointmentList *alm_list;
    AppointmentList *temp_al;
-   static int first=0;
+   static int first=1;
    time_t t, diff;
    time_t t_alarm_time;
    struct tm *Ptm;
@@ -649,9 +627,9 @@ gint cb_timer_alarms(gpointer data)
 
    alm_list=NULL;
 
-   if (!first) {
+   if (first) {
       alarms_write_file();
-      first=1;
+      first=0;
    }
 
    time(&t);
@@ -1011,7 +989,7 @@ int alarms_init(unsigned char skip_past_alarms,
    found_uptodate=0;
    in=jp_open_home_file(EPN".alarms", "r");
    if (!in) {
-      jp_logf(JP_LOG_WARN, _("Unable to open %s.alarms file\n"), EPN);
+      jp_logf(JP_LOG_WARN, _("Unable to open file: %s%s\n"), EPN, ".alarms");
       return EXIT_FAILURE;
    }
 
@@ -1025,6 +1003,9 @@ int alarms_init(unsigned char skip_past_alarms,
 	 if (n==5) {
 	    found_uptodate=1;
 	 }
+         /* Avoid corner case of retriggering alarms that are set for 
+          * exactly the same time as the UPTODATE timestamp */
+         min = min + 1;
 	 jp_logf(JP_LOG_DEBUG, "UPTODATE %d %d %d %d %d\n", year, mon, day, hour, min);
       }
    }
@@ -1040,6 +1021,20 @@ int alarms_init(unsigned char skip_past_alarms,
    now.tm_isdst=-1;
    mktime(&now);
 
+   /* Corner case where current time == UPTODATE time.
+    * Must adjust current time forward by 1 minute so that upper 
+    * bound of search range (current time) is not smaller than
+    * lower bound (UPTODATE time) */
+   if (found_uptodate &&
+      (now.tm_min  == min-1) &&
+      (now.tm_hour == hour)  &&
+      (now.tm_mon  == mon-1) &&
+      (now.tm_year == year-1900)) {
+      now.tm_min += 1;
+      mktime(&now);
+   }
+
+   /* No UPTODATE, use current time for search lower bound */
    if (!found_uptodate) {
       alarms_write_file();
       year = now.tm_year+1900;
