@@ -1,4 +1,4 @@
-/* $Id: contact.c,v 1.11 2008/08/26 03:26:53 rikster5 Exp $ */
+/* $Id: contact.c,v 1.15 2009-09-24 03:58:19 rikster5 Exp $ */
 
 /*******************************************************************************
  * contact.c
@@ -286,7 +286,7 @@ int contact_compare(const void *v1, const void *v2)
 }
 
 /*
- * sort_order: 0=descending,  1=ascending
+ * sort_order: SORT_ASCENDING | SORT_DESCENDING
  */
 int contacts_sort(ContactList **cl, int sort_order)
 {
@@ -361,7 +361,7 @@ int copy_address_ai_to_contact_ai(const struct AddressAppInfo *aai, struct Conta
 
    memcpy(&cai->category, &aai->category, sizeof(struct CategoryAppInfo));
 
-   memset(&cai->unknown1, '\0', 26);
+   memset(&cai->internal, '\0', 26);
 
    for (i=0; i<NUM_CONTACT_ENTRIES; i++) {
       c_entry = cont_addr_map[i*2];
@@ -377,12 +377,12 @@ int copy_address_ai_to_contact_ai(const struct AddressAppInfo *aai, struct Conta
    }
 
    /* The rest of the labels do not exist in address */
-   if (cai->version==10) {
+   if (cai->type==contacts_v10) {
       for (i=NUM_CONTACT_ENTRIES; i<NUM_CONTACT_V10_LABELS; i++) {
 	 cai->labels[i][0]='\0';
       }
    }
-   if (cai->version==11) {
+   if (cai->type==contacts_v11) {
       for (i=NUM_CONTACT_ENTRIES; i<NUM_CONTACT_V11_LABELS; i++) {
 	 cai->labels[i][0]='\0';
       }
@@ -618,8 +618,8 @@ int get_contacts(ContactList **contact_list, int sort_order)
    return get_contacts2(contact_list, sort_order, 1, 1, 1, CATEGORY_ALL);
 }
 /*
- * sort_order: 0=descending,  1=ascending
- * modified, deleted and private, 0 for no, 1 for yes, 2 for use prefs
+ * sort_order: SORT_ASCENDING | SORT_DESCENDING
+ * modified, deleted, private: 0 for no, 1 for yes, 2 for use prefs
  */
 int get_contacts2(ContactList **contact_list, int sort_order,
 		  int modified, int deleted, int privates, int category)
@@ -739,9 +739,6 @@ int get_contacts2(ContactList **contact_list, int sort_order,
 
    jp_free_DB_records(&records);
 
-#ifdef JPILOT_DEBUG
-   print_contact_list(contact_list);
-#endif
    contacts_sort(contact_list, sort_order);
 
    jp_logf(JP_LOG_DEBUG, "Leaving get_contacts2()\n");
