@@ -1,4 +1,4 @@
-/* $Id: datebook.c,v 1.51 2007/12/18 00:41:42 rikster5 Exp $ */
+/* $Id: datebook.c,v 1.59 2009-09-19 20:59:48 rikster5 Exp $ */
 
 /*******************************************************************************
  * datebook.c
@@ -20,30 +20,127 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  ******************************************************************************/
 
+/********************************* Includes ***********************************/
 #include "config.h"
-#include "i18n.h"
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
-#include <pi-source.h>
-#include <pi-socket.h>
-#include <pi-datebook.h>
-#include <pi-dlp.h>
-#include <pi-file.h>
 #include <time.h>
-/*#include <sys/stat.h> */
-/*#include <sys/types.h> */
 #include <unistd.h>
 #include <utime.h>
 
-#include "datebook.h"
+#include <pi-source.h>
+#include <pi-socket.h>
+#include "jp-pi-calendar.h"
+#include <pi-dlp.h>
+#include <pi-file.h>
+
+#include "i18n.h"
 #include "utils.h"
+#include "datebook.h"
 #include "log.h"
 #include "prefs.h"
 #include "libplugin.h"
 #include "password.h"
 
-#define DATEBOOK_EOF 7
+/********************************* Constants **********************************/
+
+/****************************** Main Code *************************************/
+int appointment_on_day_list(int mon, int year, int *mask)
+{
+   struct tm tm_dom;
+   AppointmentList *tal, *al;
+   int dow, ndim, num;
+   int bit;
+   int show_priv;
+   int skip_privates;
+
+   memset(&tm_dom, 0, sizeof(tm_dom));
+   tm_dom.tm_hour=11;
+   tm_dom.tm_mday=1;
+   tm_dom.tm_mon=mon;
+   tm_dom.tm_year=year;
+
+   al = NULL;
+   /* Get private records back
+    * We want to highlight a day with a private record if we are showing or
+    * masking private records */
+   num = get_days_appointments2(&al, NULL, 2, 2, 1, NULL);
+
+   show_priv = show_privates(GET_PRIVATES);
+   skip_privates = (show_priv==HIDE_PRIVATES);
+
+   get_month_info(mon, 1, year, &dow, &ndim);
+
+   *mask = 0;
+
+   weed_datebook_list(&al, mon, year, skip_privates, mask);
+
+   for (tm_dom.tm_mday=1, bit=1; tm_dom.tm_mday<=ndim; tm_dom.tm_mday++, bit=bit<<1) {
+      if (*mask & bit) {
+	 continue;
+      }
+      mktime(&tm_dom);
+
+      for (tal=al; tal; tal = tal->next) {
+	 if (skip_privates && (tal->mappt.attrib & dlpRecAttrSecret)) continue;
+	 if (isApptOnDate(&(tal->mappt.appt), &tm_dom)) {
+	    *mask = *mask | bit;
+	    break;
+	 }
+      }
+   }
+   free_AppointmentList(&al);
+
+   return EXIT_SUCCESS;
+}
+
+/* returns 0 if times equal */
+/* returns 1 if time1 is greater (later) */
+/* returns 2 if time2 is greater (later) */
+int compareTimesToDay(struct tm *tm1, struct tm *tm2)
+{
+   unsigned int t1, t2;
+
+   t1 = tm1->tm_year*366+tm1->tm_yday;
+   t2 = tm2->tm_year*366+tm2->tm_yday;
+   if (t1 > t2 ) return 1;
+   if (t1 < t2 ) return 2;
+   return 0;
+}
+
+/* Year is years since 1900 */
+/* Mon is 0-11 */
+/* Day is 1-31 */
+/* */
+int datebook_add_exception(struct Appointment *appt, int year, int mon, int day)
+{
+   struct tm *new_exception, *Ptm;
+
+   if (appt->exceptions==0) {
+      appt->exception=NULL;
+   }
+
+   new_exception = malloc((appt->exceptions + 1) * sizeof(struct tm));
+   if (!new_exception) {
+      jp_logf(JP_LOG_WARN, "datebook_add_exception(): %s\n", _("Out of memory"));
+      return EXIT_FAILURE;
+   }
+   memcpy(new_exception, appt->exception, (appt->exceptions) * sizeof(struct tm));
+   free(appt->exception);
+   appt->exceptions++;
+   appt->exception = new_exception;
+   Ptm = &(appt->exception[appt->exceptions - 1]);
+   Ptm->tm_year = year;
+   Ptm->tm_mon = mon;
+   Ptm->tm_mday = day;
+   Ptm->tm_hour = 0;
+   Ptm->tm_min = 0;
+   Ptm->tm_sec = 0;
+   Ptm->tm_isdst = -1;
+   mktime(Ptm);
+   return EXIT_SUCCESS;
+}
 
 int datebook_compare(const void *v1, const void *v2)
 {
@@ -61,11 +158,50 @@ int datebook_compare(const void *v1, const void *v2)
    }
 
    /* Jim Rees pointed out my sorting error */
-   /* return ((appt1->begin.tm_hour*60 + appt1->begin.tm_min) > */
    return ((appt1->begin.tm_hour*60 + appt1->begin.tm_min) -
 	   (appt2->begin.tm_hour*60 + appt2->begin.tm_min));
 }
 
+/*
+ * If a copy is made, then it should be freed through free_Appointment
+ */
+int datebook_copy_appointment(struct Appointment *a1,
+			     struct Appointment **a2)
+{
+   long datebook_version;
+
+   get_pref(PREF_DATEBOOK_VERSION, &datebook_version, NULL);
+
+   *a2=malloc(sizeof(struct Appointment));
+   if (!(*a2)) {
+      jp_logf(JP_LOG_WARN, "datebook_copy_appointment(): %s\n", _("Out of memory"));
+      return EXIT_FAILURE;
+   }
+   memcpy(*a2, a1, sizeof(struct Appointment));
+
+   (*a2)->exception = malloc(a1->exceptions * sizeof(struct tm));
+   if (!(*a2)->exception) {
+      jp_logf(JP_LOG_WARN, "datebook_copy_appointment(): %s 2\n", _("Out of memory"));
+      return EXIT_FAILURE;
+   }
+   memcpy((*a2)->exception, a1->exception, a1->exceptions * sizeof(struct tm));
+
+   if (a1->description) {
+      (*a2)->description=strdup(a1->description);
+   }
+   if (a1->note) {
+      (*a2)->note=strdup(a1->note);
+   }
+
+   if (datebook_version) {
+      if (a1->location) {
+         (*a2)->location=strdup(a1->location);
+      } 
+   }
+
+   return EXIT_SUCCESS;
+}
+
 int datebook_sort(AppointmentList **al,
                   int (*compare_func)(const void*, const void*))
 {
@@ -74,12 +210,10 @@ int datebook_sort(AppointmentList **al,
    int count, i;
 
    /* Count the entries in the list */
-   for (count=0, temp_al=*al; temp_al; temp_al=temp_al->next, count++) {
-      ;
-   }
+   for (count=0, temp_al=*al; temp_al; temp_al=temp_al->next, count++) {}
 
    if (count<2) {
-      /* We don't have to sort less than 2 items */
+      /* No need to sort 0 or 1 items */
       return EXIT_SUCCESS;
    }
 
@@ -112,57 +246,6 @@ int datebook_sort(AppointmentList **al,
 }
 
 #ifdef ENABLE_DATEBK
-int db3_hack_date(struct Appointment *appt, struct tm *today)
-{
-   int t1, t2;
-
-   if (today==NULL) {
-      return EXIT_SUCCESS;
-   }
-   if (!appt->note) {
-      return EXIT_SUCCESS;
-   }
-   if (strlen(appt->note) > 8) {
-      if ((appt->note[0]=='#') && (appt->note[1]=='#')) {
-	 if (appt->note[2]=='f' || appt->note[2]=='F') {
-	    /* Check to see if its in the future */
-	    t1 = appt->begin.tm_mday + appt->begin.tm_mon*31 + appt->begin.tm_year*372;
-	    t2 = today->tm_mday + today->tm_mon*31 + today->tm_year*372;
-	    if (t1 > t2) return EXIT_SUCCESS;
-	    /* We found some silly hack, so we lie about the date */
-	    /*memcpy(&(appt->begin), today, sizeof(struct tm));*/
-	    /*memcpy(&(appt->end), today, sizeof(struct tm));*/
-	    appt->begin.tm_mday = today->tm_mday;
-	    appt->begin.tm_mon = today->tm_mon;
-	    appt->begin.tm_year = today->tm_year;
-	    appt->begin.tm_wday = today->tm_wday;
-	    appt->begin.tm_yday = today->tm_yday;
-	    appt->begin.tm_isdst = today->tm_isdst;
-	    appt->end.tm_mday = today->tm_mday;
-	    appt->end.tm_mon = today->tm_mon;
-	    appt->end.tm_year = today->tm_year;
-	    appt->end.tm_wday = today->tm_wday;
-	    appt->end.tm_yday = today->tm_yday;
-	    appt->end.tm_isdst = today->tm_isdst;
-	    /* If the appointment has an end date, and today is past the end
-	     * date, because of this hack we would never be able to view
-	     * it anymore (or delete it).
-	     */
-	    if (!(appt->repeatForever)) {
-	       if (compareTimesToDay(today, &(appt->repeatEnd))==1) {
-		  /* end date is before start date, illegal appointment */
-		  /* make it legal, by only floating up to the end date */
-		  memcpy(&(appt->begin), &(appt->repeatEnd), sizeof(struct tm));
-		  memcpy(&(appt->end), &(appt->repeatEnd), sizeof(struct tm));
-	       }
-	    }
-	 }
-      }
-   }
-   return EXIT_SUCCESS;
-}
-
-/* Note should be pretty much validated by now */
 void db3_fill_struct(char *note, int type, struct db4_struct *db4)
 {
    /* jp_logf(JP_LOG_WARN, "db3_fill_struct()\n"); */
@@ -215,6 +298,55 @@ void db3_fill_struct(char *note, int type, struct db4_struct *db4)
    /* Byte 19 is a carriage return */
 }
 
+int db3_hack_date(struct Appointment *appt, struct tm *today)
+{
+   int t1, t2;
+
+   if (today==NULL) {
+      return EXIT_SUCCESS;
+   }
+   if (!appt->note) {
+      return EXIT_SUCCESS;
+   }
+   if (strlen(appt->note) > 8) {
+      if ((appt->note[0]=='#') && (appt->note[1]=='#')) {
+	 if (appt->note[2]=='f' || appt->note[2]=='F') {
+	    /* Check to see if its in the future */
+	    t1 = appt->begin.tm_mday + appt->begin.tm_mon*31 + appt->begin.tm_year*372;
+	    t2 = today->tm_mday + today->tm_mon*31 + today->tm_year*372;
+	    if (t1 > t2) return EXIT_SUCCESS;
+	    /* We found some silly hack, so we lie about the date */
+	    /* memcpy(&(appt->begin), today, sizeof(struct tm));*/
+	    /* memcpy(&(appt->end), today, sizeof(struct tm));*/
+	    appt->begin.tm_mday = today->tm_mday;
+	    appt->begin.tm_mon = today->tm_mon;
+	    appt->begin.tm_year = today->tm_year;
+	    appt->begin.tm_wday = today->tm_wday;
+	    appt->begin.tm_yday = today->tm_yday;
+	    appt->begin.tm_isdst = today->tm_isdst;
+	    appt->end.tm_mday = today->tm_mday;
+	    appt->end.tm_mon = today->tm_mon;
+	    appt->end.tm_year = today->tm_year;
+	    appt->end.tm_wday = today->tm_wday;
+	    appt->end.tm_yday = today->tm_yday;
+	    appt->end.tm_isdst = today->tm_isdst;
+	    /* If the appointment has an end date, and today is past the end
+	     * date, because of this hack we would never be able to view
+	     * it anymore (or delete it).  */
+	    if (!(appt->repeatForever)) {
+	       if (compareTimesToDay(today, &(appt->repeatEnd))==1) {
+		  /* end date is before start date, illegal appointment */
+		  /* make it legal, by only floating up to the end date */
+		  memcpy(&(appt->begin), &(appt->repeatEnd), sizeof(struct tm));
+		  memcpy(&(appt->end), &(appt->repeatEnd), sizeof(struct tm));
+	       }
+	    }
+	 }
+      }
+   }
+   return EXIT_SUCCESS;
+}
+
 /*
  * Parses the note tag and looks for db3 or db4 tags.
  * returns -1: error, 0: false, 1: true
@@ -311,178 +443,225 @@ int db3_parse_tag(char *note, int *type, struct db4_struct *db4)
 }
 #endif
 
-int pc_datebook_write(struct Appointment *appt, PCRecType rt,
-		      unsigned char attrib, unsigned int *unique_id)
-{
-#ifndef PILOT_LINK_0_12
-   unsigned char record[65536];
-   int rec_len;
-#else /* PILOT_LINK_0_12 */
-   pi_buffer_t *RecordBuffer;
-#endif /* PILOT_LINK_0_12 */
-   buf_rec br;
-   long char_set;
-
-   get_pref(PREF_CHAR_SET, &char_set, NULL);
-   if (char_set != CHAR_SET_LATIN1) {
-      if (appt->description) charset_j2p(appt->description, strlen(appt->description)+1, char_set);
-      if (appt->note) charset_j2p(appt->note, strlen(appt->note)+1, char_set);
-   }
-
-#ifndef PILOT_LINK_0_12
-   rec_len = pack_Appointment(appt, record, 65535);
-   if (!rec_len) {
-#else /* PILOT_LINK_0_12 */
-   RecordBuffer = pi_buffer_new(0);
-   if (pack_Appointment(appt, RecordBuffer, datebook_v1) == -1) {
-#endif /* PILOT_LINK_0_12 */
-      PRINT_FILE_LINE;
-      jp_logf(JP_LOG_WARN, "pack_Appointment %s\n", _("error"));
-      return EXIT_FAILURE;
-   }
-   br.rt=rt;
-   br.attrib = attrib;
-#ifndef PILOT_LINK_0_12
-   br.buf = record;
-   br.size = rec_len;
-#else /* PILOT_LINK_0_12 */
-   br.buf = RecordBuffer->data;
-   br.size = RecordBuffer->used;
-#endif /* PILOT_LINK_0_12 */
-   /* Keep unique ID intact */
-   if ((unique_id) && (*unique_id!=0)) {
-      br.unique_id = *unique_id;
-   } else {
-      br.unique_id = 0;
-   }
-
-   jp_pc_write("DatebookDB", &br);
-   if (unique_id) {
-      *unique_id = br.unique_id;
-   }
-
-#ifdef PILOT_LINK_0_12
-   pi_buffer_free(RecordBuffer);
-#endif
-
-   return EXIT_SUCCESS;
-}
-
 void free_AppointmentList(AppointmentList **al)
 {
    AppointmentList *temp_al, *temp_al_next;
    for (temp_al = *al; temp_al; temp_al=temp_al_next) {
-      free_Appointment(&(temp_al->mappt.appt));
+      jp_free_Appointment(&(temp_al->mappt.appt));
       temp_al_next = temp_al->next;
       free(temp_al);
    }
    *al = NULL;
 }
 
+int get_datebook_app_info(struct AppointmentAppInfo *ai)
+{
+   int num;
+   int rec_size;
+   unsigned char *buf;
+   char DBname[32];
+   long datebook_version;
+
+   memset(ai, 0, sizeof(*ai));
+   /* Put at least one entry in there */
+   strcpy(ai->category.name[0], "Unfiled");
+
+   get_pref(PREF_DATEBOOK_VERSION, &datebook_version, NULL);
+
+   if (datebook_version) {
+      strcpy(DBname, "CalendarDB-PDat");
+   } else {
+      strcpy(DBname, "DatebookDB");
+   }
+
+   jp_get_app_info(DBname, &buf, &rec_size);
+   num = jp_unpack_AppointmentAppInfo(ai, buf, rec_size);
+   if (buf) {
+      free(buf);
+   }
+   if ((num<0) || (rec_size<=0)) {
+      jp_logf(JP_LOG_WARN, _("Error reading file: %s\n"), DBname);
+      return EXIT_FAILURE;
+   }
+
+   return EXIT_SUCCESS;
+}
+
+int get_days_appointments(AppointmentList **appointment_list, struct tm *now,
+			  int *total_records)
+{
+   return get_days_appointments2(appointment_list, now, 1, 1, 1, total_records);
+}
+
 /*
- * If a copy is made, then it should be freed through free_Appointment
+ * If Null is passed in for date, then all appointments will be returned
+ * modified, deleted and private, 0 for no, 1 for yes, 2 for use prefs
  */
-int datebook_copy_appointment(struct Appointment *a1,
-			     struct Appointment **a2)
+int get_days_appointments2(AppointmentList **appointment_list, struct tm *now,
+			   int modified, int deleted, int privates,
+			   int *total_records)
 {
-   *a2=malloc(sizeof(struct Appointment));
-   if (!(*a2)) {
-      jp_logf(JP_LOG_WARN, "datebook_copy_appointment(): %s\n", _("Out of memory"));
-      return EXIT_FAILURE;
-   }
-   memcpy(*a2, a1, sizeof(struct Appointment));
+   GList *records;
+   GList *temp_list;
+   int recs_returned, num;
+   struct Appointment appt;
+   AppointmentList *temp_a_list;
+   long keep_modified, keep_deleted;
+   int keep_priv;
+   buf_rec *br;
+   long char_set;
+   long datebook_version;
+   char *buf;
+   pi_buffer_t *RecordBuffer;
+#ifdef ENABLE_DATEBK
+   long use_db3_tags;
+   time_t ltime;
+   struct tm today;
+#endif
 
-   (*a2)->exception = malloc(a1->exceptions * sizeof(struct tm));
-   if (!(*a2)->exception) {
-      jp_logf(JP_LOG_WARN, "datebook_copy_appointment(): %s 2\n", _("Out of memory"));
-      return EXIT_FAILURE;
-   }
-   memcpy((*a2)->exception, a1->exception, a1->exceptions * sizeof(struct tm));
+#ifdef ENABLE_DATEBK
+   time(&ltime);
+   /* Copy into stable memory */
+   memcpy(&today, localtime(&ltime), sizeof(struct tm));
+   get_pref(PREF_USE_DB3, &use_db3_tags, NULL);
+#endif
 
-   if (a1->description) {
-      (*a2)->description=strdup(a1->description);
+   jp_logf(JP_LOG_DEBUG, "get_days_appointments()\n");
+
+   if (modified==2) {
+      get_pref(PREF_SHOW_MODIFIED, &keep_modified, NULL);
+   } else {
+      keep_modified = modified;
    }
-   if (a1->note) {
-      (*a2)->note=strdup(a1->note);
+   if (deleted==2) {
+      get_pref(PREF_SHOW_DELETED, &keep_deleted, NULL);
+   } else {
+      keep_deleted = deleted;
+   }
+   if (privates==2) {
+      keep_priv = show_privates(GET_PRIVATES);
+   } else {
+      keep_priv = privates;
+   }
+   get_pref(PREF_CHAR_SET, &char_set, NULL);
+
+   *appointment_list=NULL;
+   recs_returned = 0;
+
+   get_pref(PREF_DATEBOOK_VERSION, &datebook_version, NULL);
+
+   if (datebook_version) {
+      num = jp_read_DB_files("CalendarDB-PDat", &records);
+   } else {
+      num = jp_read_DB_files("DatebookDB", &records);
+   }
+   if (-1 == num)
+     return 0;
+
+   if (total_records) *total_records = num;
+
+   for (temp_list = records; temp_list; temp_list = temp_list->next) {
+      if (temp_list->data) {
+	 br=temp_list->data;
+      } else {
+	 continue;
+      }
+      if (!br->buf) {
+	 continue;
+      }
+
+      if ( ((br->rt==DELETED_PALM_REC)  && (!keep_deleted)) ||
+	   ((br->rt==DELETED_PC_REC)    && (!keep_deleted)) ||
+	   ((br->rt==MODIFIED_PALM_REC) && (!keep_modified)) ) {
+	 continue;
+      }
+      if ((keep_priv != SHOW_PRIVATES) &&
+	  (br->attrib & dlpRecAttrSecret)) {
+	 continue;
+      }
+
+      appt.exception=NULL;
+      appt.description=NULL;
+      appt.note=NULL;
+      appt.location=NULL;
+
+      RecordBuffer = pi_buffer_new(br->size);
+      memcpy(RecordBuffer->data, br->buf, br->size);
+      RecordBuffer->used = br->size;
+      if (jp_unpack_Appointment(&appt, RecordBuffer, datebook_v1) == -1) {
+	 pi_buffer_free(RecordBuffer);
+	 continue;
+      }
+      pi_buffer_free(RecordBuffer);
+
+#ifdef ENABLE_DATEBK
+      if (use_db3_tags) {
+	 db3_hack_date(&appt, &today);
+      }
+#endif
+      if (now!=NULL) {
+	 if (!isApptOnDate(&appt, now)) {
+	    jp_free_Appointment(&appt);
+	    continue;
+	 }
+      }
+
+      if (appt.description) {
+         buf = charset_p2newj(appt.description, -1, char_set);
+         if (buf) {
+            free(appt.description);
+            appt.description = buf;
+         }
+      }
+      if (appt.note) {
+         buf = charset_p2newj(appt.note, -1, char_set);
+         if (buf) {
+	    free(appt.note);
+	    appt.note = buf;
+	 }
+      }
+      if (appt.location) {
+         buf = charset_p2newj(appt.location, -1, char_set);
+         if (buf) {
+	    free(appt.location);
+	    appt.location = buf;
+	 }
+      }
+
+      temp_a_list = malloc(sizeof(AppointmentList));
+      if (!temp_a_list) {
+	 jp_logf(JP_LOG_WARN, "get_days_appointments(): %s\n", _("Out of memory"));
+	 jp_free_Appointment(&appt);
+	 break;
+      }
+      memcpy(&(temp_a_list->mappt.appt), &appt, sizeof(struct Appointment));
+      temp_a_list->app_type = DATEBOOK;
+      temp_a_list->mappt.rt = br->rt;
+      temp_a_list->mappt.attrib = br->attrib;
+      temp_a_list->mappt.unique_id = br->unique_id;
+      temp_a_list->next = *appointment_list;
+      *appointment_list = temp_a_list;
+      recs_returned++;
    }
 
-   return EXIT_SUCCESS;
-}
+   jp_free_DB_records(&records);
 
+   datebook_sort(appointment_list, datebook_compare);
 
-/* Year is years since 1900 */
-/* Mon is 0-11 */
-/* Day is 1-31 */
-/* */
-int datebook_add_exception(struct Appointment *appt, int year, int mon, int day)
-{
-   struct tm *new_exception, *Ptm;
+   jp_logf(JP_LOG_DEBUG, "Leaving get_days_appointments()\n");
 
-   if (appt->exceptions==0) {
-      appt->exception=NULL;
-   }
-
-   new_exception = malloc((appt->exceptions + 1) * sizeof(struct tm));
-   if (!new_exception) {
-      jp_logf(JP_LOG_WARN, "datebook_add_exception(): %s\n", _("Out of memory"));
-      return EXIT_FAILURE;
-   }
-   memcpy(new_exception, appt->exception, (appt->exceptions) * sizeof(struct tm));
-   free(appt->exception);
-   appt->exceptions++;
-   appt->exception = new_exception;
-   Ptm = &(appt->exception[appt->exceptions - 1]);
-   Ptm->tm_year = year;
-   Ptm->tm_mon = mon;
-   Ptm->tm_mday = day;
-   Ptm->tm_hour = 0;
-   Ptm->tm_min = 0;
-   Ptm->tm_sec = 0;
-   Ptm->tm_isdst = -1;
-   mktime(Ptm);
-   return EXIT_SUCCESS;
-}
-
-/*returns 0 if times equal */
-/*returns 1 if time1 is greater (later) */
-/*returns 2 if time2 is greater (later) */
-/*
-int compareTimesToSec(struct tm *tm1, struct tm *tm2)
-{
-   time_t t1, t2;
-
-   t1 = mktime(tm1);
-   t2 = mktime(tm2);
-   if (t1 > t2) return 1;
-   if (t1 < t2) return 2;
-   return 0;
-}
-*/
-/*returns 0 if times equal */
-/*returns 1 if time1 is greater (later) */
-/*returns 2 if time2 is greater (later) */
-int compareTimesToDay(struct tm *tm1, struct tm *tm2)
-{
-   unsigned int t1, t2;
-
-   t1 = tm1->tm_year*366+tm1->tm_yday;
-   t2 = tm2->tm_year*366+tm2->tm_yday;
-   if (t1 > t2 ) return 1;
-   if (t1 < t2 ) return 2;
-   return 0;
+   return recs_returned;
 }
 
 unsigned int isApptOnDate(struct Appointment *appt, struct tm *date)
 {
-/*   long fdow; */
    unsigned int ret;
    unsigned int r;
    int week1, week2;
    int dow, ndim;
    int i;
    /* days_in_month is adjusted for leap year with the date structure */
-   int days_in_month[]={31,28,31,30,31,30,31,31,30,31,30,31
-   };
+   int days_in_month[]={31,28,31,30,31,30,31,31,30,31,30,31};
    int exception_days;
    static int days, begin_days;
 
@@ -530,20 +709,11 @@ unsigned int isApptOnDate(struct Appointment *appt, struct tm *date)
     case repeatWeekly:
       get_month_info(date->tm_mon, date->tm_mday, date->tm_year, &dow, &ndim);
       /* See if the appointment repeats on this day */
-      /*
-      if (appt->repeatWeekstart > 1) {
-	 appt->repeatWeekstart = 1;
-      }
-      if (appt->repeatWeekstart < 0) {
-	 appt->repeatWeekstart = 0;
-      }
-      */
-      /*if (!(appt->repeatDays[dow + appt->repeatWeekstart])) {*/
       if (!(appt->repeatDays[dow])) {
 	 ret = FALSE;
 	 break;
       }
-      /*See if we are in a week that is repeated in */
+      /* See if we are in a week that is repeated in */
       begin_days = dateToDays(&(appt->begin));
       days = dateToDays(date);
 
@@ -625,7 +795,7 @@ unsigned int isApptOnDate(struct Appointment *appt, struct tm *date)
       jp_logf(JP_LOG_WARN, _("Unknown repeatType (%d) found in DatebookDB\n"),
 	   appt->repeatType);
       ret = FALSE;
-   }/*switch */
+   }/* switch */
 
    /* Check for exceptions */
    if (ret && appt->exceptions) {
@@ -649,25 +819,54 @@ unsigned int isApptOnDate(struct Appointment *appt, struct tm *date)
    return ret;
 }
 
-int get_datebook_app_info(struct AppointmentAppInfo *ai)
+int pc_datebook_write(struct Appointment *appt, PCRecType rt,
+		      unsigned char attrib, unsigned int *unique_id)
 {
-   int num;
-   int rec_size;
-   unsigned char *buf;
+   pi_buffer_t *RecordBuffer;
+   buf_rec br;
+   long char_set;
+   long datebook_version;
 
-   memset(ai, 0, sizeof(*ai));
-   /* Put at least one entry in there */
-   strcpy(ai->category.name[0], "Unfiled");
+   get_pref(PREF_DATEBOOK_VERSION, &datebook_version, NULL);
 
-   jp_get_app_info("DatebookDB", &buf, &rec_size);
-   num = unpack_AppointmentAppInfo(ai, buf, rec_size);
-   if (buf) {
-      free(buf);
+   get_pref(PREF_CHAR_SET, &char_set, NULL);
+   if (char_set != CHAR_SET_LATIN1) {
+      if (appt->description) charset_j2p(appt->description, strlen(appt->description)+1, char_set);
+      if (appt->note) charset_j2p(appt->note, strlen(appt->note)+1, char_set);
+      if (datebook_version) {
+         if (appt->location) 
+            charset_j2p(appt->location, strlen(appt->location)+1, char_set);
+      }
    }
-   if ((num<0) || (rec_size<=0)) {
-      jp_logf(JP_LOG_WARN, _("Error reading file: %s\n"), "DatebookDB.pdb");
+
+   RecordBuffer = pi_buffer_new(0);
+   if (jp_pack_Appointment(appt, RecordBuffer, datebook_v1) == -1) {
+      PRINT_FILE_LINE;
+      jp_logf(JP_LOG_WARN, "jp_pack_Appointment %s\n", _("error"));
       return EXIT_FAILURE;
    }
+   br.rt=rt;
+   br.attrib = attrib;
+   br.buf = RecordBuffer->data;
+   br.size = RecordBuffer->used;
+   /* Keep unique ID intact */
+   if ((unique_id) && (*unique_id!=0)) {
+      br.unique_id = *unique_id;
+   } else {
+      br.unique_id = 0;
+   }
+
+   if (datebook_version) {
+      jp_pc_write("CalendarDB-PDat", &br);
+   } else {
+      jp_pc_write("DatebookDB", &br);
+   }
+
+   if (unique_id) {
+      *unique_id = br.unique_id;
+   }
+
+   pi_buffer_free(RecordBuffer);
 
    return EXIT_SUCCESS;
 }
@@ -704,10 +903,8 @@ int weed_datebook_list(AppointmentList **al, int mon, int year,
    days = dateToDays(&tm_fdom);
 
    next_al=NULL;
-   /*
-    * We are going to try to shrink the linked list since we are about to
-    * search though it ~30 times.
-    */
+   /* We are going to try to shrink the linked list since we are about to
+    * search though it ~30 times.  */
    for (prev_al=NULL, tal=*al; tal; tal = next_al) {
       if (skip_privates && (tal->mappt.attrib & dlpRecAttrSecret)) {
 	 next_al=tal->next;
@@ -810,7 +1007,7 @@ int weed_datebook_list(AppointmentList **al, int mon, int year,
 	    *al=tal->next;
 	 }
 	 next_al=tal->next;
-	 free_Appointment(&(tal->mappt.appt));
+	 jp_free_Appointment(&(tal->mappt.appt));
 	 free(tal);
       } else {
 	 prev_al=tal;
@@ -820,227 +1017,3 @@ int weed_datebook_list(AppointmentList **al, int mon, int year,
    return EXIT_SUCCESS;
 }
 
-int appointment_on_day_list(int mon, int year, int *mask)
-{
-   struct tm tm_dom;
-   AppointmentList *tal, *al;
-   int dow, ndim, num;
-   int bit;
-   int show_priv;
-   int skip_privates;
-
-   memset(&tm_dom, 0, sizeof(tm_dom));
-   tm_dom.tm_hour=11;
-   tm_dom.tm_mday=1;
-   tm_dom.tm_mon=mon;
-   tm_dom.tm_year=year;
-
-   al = NULL;
-   /* Get private records back
-    * We want to highlight a day with a private record if we are showing or
-    * masking private records */
-   num = get_days_appointments2(&al, NULL, 2, 2, 1, NULL);
-
-   show_priv = show_privates(GET_PRIVATES);
-   skip_privates = (show_priv==HIDE_PRIVATES);
-
-   get_month_info(mon, 1, year, &dow, &ndim);
-
-   *mask = 0;
-
-   weed_datebook_list(&al, mon, year, skip_privates, mask);
-
-   for (tm_dom.tm_mday=1, bit=1; tm_dom.tm_mday<=ndim; tm_dom.tm_mday++, bit=bit<<1) {
-      if (*mask & bit) {
-	 continue;
-      }
-      mktime(&tm_dom);
-
-      for (tal=al; tal; tal = tal->next) {
-	 if (skip_privates && (tal->mappt.attrib & dlpRecAttrSecret)) continue;
-	 if (isApptOnDate(&(tal->mappt.appt), &tm_dom)) {
-	    *mask = *mask | bit;
-	    break;
-	 }
-      }
-   }
-   free_AppointmentList(&al);
-
-   return EXIT_SUCCESS;
-}
-
-int get_days_appointments(AppointmentList **appointment_list, struct tm *now,
-			  int *total_records)
-{
-   return get_days_appointments2(appointment_list, now, 1, 1, 1, total_records);
-}
-/*
- * If Null is passed in for date, then all appointments will be returned
- * modified, deleted and private, 0 for no, 1 for yes, 2 for use prefs
- */
-int get_days_appointments2(AppointmentList **appointment_list, struct tm *now,
-			   int modified, int deleted, int privates,
-			   int *total_records)
-{
-   GList *records;
-   GList *temp_list;
-   int recs_returned, i, num;
-   struct Appointment appt;
-   AppointmentList *temp_a_list;
-   long keep_modified, keep_deleted;
-   int keep_priv;
-   buf_rec *br;
-   long char_set;
-   char *buf;
-   size_t len;
-#ifdef PILOT_LINK_0_12
-   pi_buffer_t *RecordBuffer;
-#endif /* PILOT_LINK_0_12 */
-#ifdef ENABLE_DATEBK
-   long use_db3_tags;
-   time_t ltime;
-   struct tm *Ptoday, today;
-#endif
-
-#ifdef ENABLE_DATEBK
-   time(&ltime);
-   Ptoday = localtime(&ltime);
-   /* Copy into stable memory */
-   memcpy(&today, Ptoday, sizeof(struct tm));
-   get_pref(PREF_USE_DB3, &use_db3_tags, NULL);
-#endif
-
-   jp_logf(JP_LOG_DEBUG, "get_days_appointments()\n");
-
-   if (modified==2) {
-      get_pref(PREF_SHOW_MODIFIED, &keep_modified, NULL);
-   } else {
-      keep_modified = modified;
-   }
-   if (deleted==2) {
-      get_pref(PREF_SHOW_DELETED, &keep_deleted, NULL);
-   } else {
-      keep_deleted = deleted;
-   }
-   if (privates==2) {
-      keep_priv = show_privates(GET_PRIVATES);
-   } else {
-      keep_priv = privates;
-   }
-
-   *appointment_list=NULL;
-   recs_returned = 0;
-
-   num = jp_read_DB_files("DatebookDB", &records);
-   if (-1 == num)
-     return 0;
-
-   if (total_records) *total_records = num;
-
-   for (i=0, temp_list = records; temp_list; temp_list = temp_list->next, i++) {
-      if (temp_list->data) {
-	 br=temp_list->data;
-      } else {
-	 continue;
-      }
-      if (!br->buf) {
-	 continue;
-      }
-
-      if ( ((br->rt==DELETED_PALM_REC)  && (!keep_deleted)) ||
-	   ((br->rt==DELETED_PC_REC)    && (!keep_deleted)) ||
-	   ((br->rt==MODIFIED_PALM_REC) && (!keep_modified)) ) {
-	 continue;
-      }
-      if ((keep_priv != SHOW_PRIVATES) &&
-	  (br->attrib & dlpRecAttrSecret)) {
-	 continue;
-      }
-
-      appt.exception=NULL;
-      appt.description=NULL;
-      appt.note=NULL;
-#ifndef PILOT_LINK_0_12
-      num = unpack_Appointment(&appt, br->buf, br->size);
-#endif /* ! PILOT_LINK_0_12 */
-
-#ifndef PILOT_LINK_0_12
-      if (num <= 0) {
-#else /* PILOT_LINK_0_12 */
-      RecordBuffer = pi_buffer_new(br->size);
-      memcpy(RecordBuffer->data, br->buf, br->size);
-      RecordBuffer->used = br->size;
-      if (unpack_Appointment(&appt, RecordBuffer, datebook_v1) == -1) {
-	 pi_buffer_free(RecordBuffer);
-#endif /* PILOT_LINK_0_12 */
-	 continue;
-      }
-#ifdef PILOT_LINK_0_12
-      pi_buffer_free(RecordBuffer);
-#endif /* PILOT_LINK_0_12 */
-
-#ifdef ENABLE_DATEBK
-      if (use_db3_tags) {
-	 db3_hack_date(&appt, &today);
-      }
-#endif
-      if (now!=NULL) {
-	 if (!isApptOnDate(&appt, now)) {
-	    free_Appointment(&appt);
-	    continue;
-	 }
-      }
-
-      get_pref(PREF_CHAR_SET, &char_set, NULL);
-
-      if (appt.description) {
-	 if ((buf = malloc((len = strlen(appt.description)*2+1))) != NULL) {
-	    multibyte_safe_strncpy(buf, appt.description, len);
-	    charset_p2j(buf, len, char_set);
-	    if (strlen(buf) > strlen(appt.description)) {
-	       free(appt.description);
-	       appt.description = strdup(buf);
-	    } else {
-	       multibyte_safe_strncpy(appt.description, buf, strlen(appt.description)+1);
-	    }
-	    free(buf);
-	 }
-      }
-      if (appt.note) {
-	 if ((buf = malloc((len = strlen(appt.note)*2+1))) != NULL) {
-	    multibyte_safe_strncpy(buf, appt.note, len);
-	    charset_p2j(buf, len, char_set);
-	    if (strlen(buf) > strlen(appt.note)) {
-	       free(appt.note);
-	       appt.note = strdup(buf);
-	    } else {
-	       multibyte_safe_strncpy(appt.note, buf, strlen(appt.note)+1);
-	    }
-	    free(buf);
-	 }
-      }
-
-      temp_a_list = malloc(sizeof(AppointmentList));
-      if (!temp_a_list) {
-	 jp_logf(JP_LOG_WARN, "get_days_appointments(): %s\n", _("Out of memory"));
-	 free_Appointment(&appt);
-	 break;
-      }
-      memcpy(&(temp_a_list->mappt.appt), &appt, sizeof(struct Appointment));
-      temp_a_list->app_type = DATEBOOK;
-      temp_a_list->mappt.rt = br->rt;
-      temp_a_list->mappt.attrib = br->attrib;
-      temp_a_list->mappt.unique_id = br->unique_id;
-      temp_a_list->next = *appointment_list;
-      *appointment_list = temp_a_list;
-      recs_returned++;
-   }
-
-   jp_free_DB_records(&records);
-
-   datebook_sort(appointment_list, datebook_compare);
-
-   jp_logf(JP_LOG_DEBUG, "Leaving get_days_appointments()\n");
-
-   return recs_returned;
-}
