@@ -1,4 +1,4 @@
-/* $Id: jpilot-dump.c,v 1.31 2009/02/14 17:32:30 rousseau Exp $ */
+/* $Id: jpilot-dump.c,v 1.34 2009/09/10 06:01:54 rikster5 Exp $ */
 
 /*******************************************************************************
  * jpilot-dump.c
@@ -34,7 +34,7 @@
 #include <pi-todo.h>
 #include <pi-memo.h>
 #include <pi-address.h>
-#include <pi-datebook.h>
+#include "jp-pi-calendar.h"
 
 /* Jpilot header files */
 #include "datebook.h"
@@ -140,7 +140,7 @@ void takeoutfunnies(char *str)
    }
 }
 
-int dumpical()
+int dumpical(void)
 {
    MyAppointment *mappt;
    AppointmentList *al, *temp_list;
@@ -160,11 +160,12 @@ int dumpical()
 
    /* ICAL setup */
    get_pref(PREF_CHAR_SET, &char_set, NULL);
-   /* TODO: uncomment and warn user somehow 
    if (char_set < CHAR_SET_UTF) {
-      jp_logf(JP_LOG_WARN, _("Host character encoding is not UTF-8 based.\n Exported ical file may not be standards-compliant\n"));
+      fprintf(stderr, _("Warning: "
+                        "Host character encoding is not UTF-8 based.\n"
+                        "Exported ical file may not be standards-compliant\n"));
    }
-   */
+
    get_pref(PREF_USER, NULL, &svalue);
    g_strlcpy(text, svalue, 128);
    charset_p2j(text, 128, char_set);
@@ -378,7 +379,7 @@ int dumpical()
    return EXIT_SUCCESS;
 }
 
-int dumpbook()
+int dumpbook(void)
 {
    AppointmentList *tal, *al;
    int num, i;
@@ -644,7 +645,7 @@ int dumpbook()
    return EXIT_SUCCESS;
 }
 
-int dumpaddress()
+int dumpaddress(void)
 {
    AddressList *tal, *al;
    int num, i;
@@ -767,7 +768,7 @@ int dumpaddress()
 }
 
 
-int dumptodo()
+int dumptodo(void)
 {
    ToDoList *tal, *al;
    int num, i;
@@ -1030,7 +1031,7 @@ int dumptodo()
    return EXIT_SUCCESS;
 }
 
-int dumpmemo()
+int dumpmemo(void)
 {
    MemoList *tal, *al;
    int num,i;
