@@ -1,4 +1,4 @@
-/* $Id: libplugin.c,v 1.37 2009/02/15 14:01:44 rousseau Exp $ */
+/* $Id: libplugin.c,v 1.39 2009/08/28 05:53:39 rikster5 Exp $ */
 
 /*******************************************************************************
  * libplugin.c
@@ -231,7 +231,7 @@ int jp_get_home_file_name(char *file, char *full_name, int max_size)
    return get_home_file_name(file, full_name, max_size);
 }
 
-void jp_init()
+void jp_init(void)
 {
    jp_logf(0, "jp_init()\n");
 }
@@ -932,7 +932,7 @@ static int unpack_header(PC3RecordHeader *header, unsigned char *packed_header)
    return EXIT_SUCCESS;
 }
 
-/* Add jp_ and document */
+/* FIXME: Add jp_ and document */
 int write_header(FILE *pc_out, PC3RecordHeader *header)
 {
    unsigned long len;
