@@ -1,4 +1,4 @@
-/* $Id: monthview_gui.c,v 1.46 2008/06/19 04:12:07 rikster5 Exp $ */
+/* $Id: monthview_gui.c,v 1.51 2009-11-08 17:12:10 rousseau Exp $ */
 
 /*******************************************************************************
  * monthview_gui.c
@@ -25,7 +25,8 @@
 #include <stdlib.h>
 #include <string.h>
 #include <gtk/gtk.h>
-#include <pi-datebook.h>
+
+#include "jp-pi-calendar.h"
 
 #include "utils.h"
 #include "i18n.h"
@@ -35,7 +36,7 @@
 #include "print.h"
 
 /******************************* Global vars **********************************/
-extern int datebook_category;
+extern int datebk_category;
 extern int glob_app;
 
 GtkWidget *monthview_window=NULL;
@@ -50,7 +51,7 @@ static struct tm glob_month_date;
 
 /****************************** Prototypes ************************************/
 int display_months_appts(struct tm *glob_month_date, GtkWidget **glob_month_texts);
-void hide_show_month_boxes();
+void hide_show_month_boxes(void);
 
 /****************************** Main Code *************************************/
 static gboolean cb_destroy(GtkWidget *widget)
@@ -151,7 +152,7 @@ static void cb_enter_selected_day(GtkWidget *widget,
  * Also, set a global offset for indexing day 1.
  * Also relabel day labels.
  */
-void hide_show_month_boxes()
+void hide_show_month_boxes(void)
 {
    int n;
    int dow, ndim;
@@ -350,7 +351,7 @@ int display_months_appts(struct tm *date_in, GtkWidget **day_texts)
 	    ret = db3_parse_tag(temp_al->mappt.appt.note, &db3_type, &db4);
 	    jp_logf(JP_LOG_DEBUG, "category = 0x%x\n", db4.category);
 	    cat_bit=1<<db4.category;
-	    if (!(cat_bit & datebook_category)) {
+	    if (!(cat_bit & datebk_category)) {
 	       jp_logf(JP_LOG_DEBUG, "skipping rec not in this category\n");
 	       continue;
 	    }
@@ -375,8 +376,11 @@ int display_months_appts(struct tm *date_in, GtkWidget **day_texts)
 	    g_string_append(gstr, temp_al->mappt.appt.description);
 	    if (temp_al->mappt.appt.description) {
 	       strncat(desc, temp_al->mappt.appt.description, 36);
+               /* FIXME: This kind of truncation is bad for UTF-8 */ 
 	       desc[35]='\0';
 	    }
+            /* FIXME: Add location in parentheses (loc) as the Palm does.
+             * We would need to check strlen, etc., before adding */
 	    remove_cr_lfs(desc);
 
 	    /* Append number of anniversary years if enabled & appropriate */
