@@ -1,4 +1,7 @@
-/* plugins.h
+/* $Id: plugins.h,v 1.11 2009-11-08 17:12:10 rousseau Exp $ */
+
+/*******************************************************************************
+ * plugins.h
  * A module of J-Pilot http://jpilot.org
  * 
  * Copyright (C) 1999-2002 by Judd Montgomery
@@ -15,7 +18,8 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+ ******************************************************************************/
+
 #include "config.h"
 #ifdef  ENABLE_PLUGINS
 
@@ -29,6 +33,8 @@
 #include "libplugin.h"
 #include "prefs.h"
 
+#define MAX_NUM_PLUGINS 50
+
 struct plugin_s
 {
    char *full_path;
@@ -47,7 +53,7 @@ struct plugin_s
    int (*plugin_startup)(jp_startup_info *info);
    int (*plugin_gui)(GtkWidget *vbox, GtkWidget *hbox, unsigned int unique_id);
    int (*plugin_help)(char **text, int *width, int *height);
-   int (*plugin_print)();
+   int (*plugin_print)(void);
    int (*plugin_import)(GtkWidget *window);
    int (*plugin_export)(GtkWidget *window);
    int (*plugin_gui_cleanup)(void);
@@ -63,8 +69,8 @@ struct plugin_s
 				  unsigned char *ai_raw, int len);
 };
 
-int load_plugins();
-GList *get_plugin_list();
+int load_plugins(void);
+GList *get_plugin_list(void);
 
 /*
  * Free the search_result record list
@@ -74,7 +80,7 @@ void free_search_result(struct search_result **sr);
 /*
  * Write out the jpilot.plugins file that tells which plugins to sync
  */
-void write_plugin_sync_file();
+void write_plugin_sync_file(void);
 
 /*
  * Free the plugin_list
