@@ -1,4 +1,4 @@
-/* $Id: prefs_gui.c,v 1.58 2008/05/03 16:37:49 judd Exp $ */
+/* $Id: prefs_gui.c,v 1.71 2009/08/31 23:31:50 rikster5 Exp $ */
 
 /*******************************************************************************
  * prefs_gui.c
@@ -20,17 +20,20 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  ******************************************************************************/
 
+/********************************* Includes ***********************************/
 #include "config.h"
-#include "i18n.h"
-#include <gtk/gtk.h>
 #include <stdlib.h>
 #include <string.h>
-#include "utils.h"
-#include "prefs.h"
+#include <gtk/gtk.h>
+
 #include "prefs_gui.h"
+#include "prefs.h"
+#include "i18n.h"
+#include "utils.h"
 #include "log.h"
 #include "plugins.h"
 
+/******************************* Global vars **********************************/
 static GtkWidget *window;
 static GtkWidget *main_window;
 static GtkWidget *port_entry;
@@ -45,6 +48,17 @@ extern GtkTooltips *glob_tooltips;
 extern unsigned char skip_plugins;
 #endif
 
+/* Serial Port Menu */
+static GtkWidget *port_menu;
+GtkWidget *port_menu_item[10];
+static char *port_choices[]={
+   "other", "usb:",
+     "/dev/ttyUSB0", "/dev/ttyUSB1", "/dev/ttyUSB2", "/dev/ttyUSB3",
+     "/dev/ttyS0", "/dev/ttyS1", "/dev/ttyS2", "/dev/ttyS3",
+     NULL
+};
+
+/****************************** Main Code *************************************/
 #ifdef COLORS
 
 /* This doesn't work quite right.  There is supposedly no way to do it in GTK. */
@@ -76,19 +90,9 @@ void set_colors()
    gtk_widget_queue_draw(window);
    gtk_widget_queue_draw(main_window);
 }
-#endif
-
-/* Serial Port Menu code */
-
-static GtkWidget *port_menu;
-GtkWidget *port_menu_item[10];
-static char *port_choices[]={
-   "other", "usb:",
-     "/dev/ttyUSB0", "/dev/ttyUSB1", "/dev/ttyUSB2", "/dev/ttyUSB3",
-     "/dev/ttyS0", "/dev/ttyS1", "/dev/ttyS2", "/dev/ttyS3",
-     NULL
-};
+#endif /* #ifdef COLORS */
 
+/* Serial Port menu code */
 static void cb_serial_port_menu(GtkWidget *widget,
 				gpointer   data)
 {
@@ -145,8 +149,7 @@ int make_serial_port_menu(GtkWidget **port_menu)
 
 /* End Serial Port Menu code */
 
-static void cb_pref_menu(GtkWidget *widget,
-			 gpointer   data)
+static void cb_pref_menu(GtkWidget *widget, gpointer data)
 {
    int pref;
    int value;
@@ -178,8 +181,8 @@ int make_pref_menu(GtkWidget **pref_menu, int pref_num)
    int i, r;
    long ivalue;
    const char *svalue;
-   char format_text[MAX_PREF_VALUE];
-   char human_text[MAX_PREF_VALUE];
+   char format_text[MAX_PREF_LEN];
+   char human_text[MAX_PREF_LEN];
    time_t ltime;
    struct tm *now;
 
@@ -193,7 +196,7 @@ int make_pref_menu(GtkWidget **pref_menu, int pref_num)
 
    get_pref(pref_num, &ivalue, &svalue);
 
-   for (i=0; i<1000; i++) {
+   for (i=0; i<MAX_NUM_PREFS; i++) {
       r = get_pref_possibility(pref_num, i, format_text);
       if (r) {
 	 break;
@@ -201,13 +204,13 @@ int make_pref_menu(GtkWidget **pref_menu, int pref_num)
       switch (pref_num) {
        case PREF_SHORTDATE:
        case PREF_TIME:
-	 jp_strftime(human_text, MAX_PREF_VALUE, format_text, now);
+	 jp_strftime(human_text, MAX_PREF_LEN, format_text, now);
 	 break;
        case PREF_LONGDATE:
-	 jp_strftime(human_text, MAX_PREF_VALUE, _(format_text), now);
+	 jp_strftime(human_text, MAX_PREF_LEN, _(format_text), now);
 	 break;
        default:
-	 strncpy(human_text, format_text, MAX_PREF_VALUE);
+	 strncpy(human_text, format_text, MAX_PREF_LEN);
 	 break;
       }
       menu_item = gtk_radio_menu_item_new_with_label(
@@ -302,11 +305,6 @@ void cb_checkbox_set_pref(GtkWidget *widget, gpointer data)
    pref = GPOINTER_TO_INT(data);
    value = GTK_TOGGLE_BUTTON(widget)->active;
    set_pref(pref, value, NULL, TRUE);
-   /* FIXME: Should eliminate references to SYNC_MEMO32 and use the preference
-    * SYNC_MEMO instead */
-   if (pref==PREF_SYNC_MEMO) {
-      set_pref(PREF_SYNC_MEMO32, value, NULL, TRUE);
-   }
 }
 
 /*
@@ -316,37 +314,16 @@ void cb_checkbox_set_pref(GtkWidget *widget, gpointer data)
 void cb_radio_set_pref(GtkWidget *widget, gpointer data)
 {
    unsigned long pref, value;
-   long ivalue;
-   const char *cstr;
 
    pref=GPOINTER_TO_INT(data);
    value=pref & 0xFFFF;
    pref >>= 16;
    set_pref(pref, value, NULL, TRUE);
-   /* FIXME: Hack which preserves MEMO32 pref.  This should be
-    * eliminated in favor of just PREF_MEMO_VERSION */
-   if (pref==PREF_MEMO_VERSION) {
-      if (value==2) {
-         set_pref(PREF_MEMO32_MODE, 1, NULL, TRUE);
-
-         get_pref(PREF_SYNC_MEMO, &ivalue, &cstr);
-         if (ivalue) {
-            set_pref(PREF_SYNC_MEMO32, 1, NULL, TRUE);
-         } else {
-            set_pref(PREF_SYNC_MEMO32, 0, NULL, TRUE);
-         }
-
-      } else {
-         set_pref(PREF_MEMO32_MODE, 0, NULL, TRUE);
-         set_pref(PREF_SYNC_MEMO32, 0, NULL, TRUE);
-      }
-   }
 }
 
 
 #ifdef ENABLE_PLUGINS
-void cb_sync_plugin(GtkWidget *widget,
-		    gpointer data)
+void cb_sync_plugin(GtkWidget *widget, gpointer data)
 {
    GList *plugin_list, *temp_list;
    struct plugin_s *Pplugin;
@@ -376,7 +353,7 @@ void cb_sync_plugin(GtkWidget *widget,
 
 static gboolean cb_destroy(GtkWidget *widget)
 {
-   jp_logf(JP_LOG_DEBUG, "Cleanup\n");
+   jp_logf(JP_LOG_DEBUG, "Pref GUI Cleanup\n");
 
    pref_write_rc_file();
 
@@ -398,11 +375,11 @@ static void cb_quit(GtkWidget *widget, gpointer data)
 }
 
 /* This function adds a simple option checkbutton for the supplied text +
- * option.
- */
-static void
-add_checkbutton(const char *text, int which, GtkWidget *vbox,
-		void cb(GtkWidget *widget, gpointer data))
+ * option.  */
+static void add_checkbutton(const char *text, 
+                            int which, 
+                            GtkWidget *vbox, 
+                            void cb(GtkWidget *widget, gpointer data))
 {
    /* Create button */
    GtkWidget *checkbutton = gtk_check_button_new_with_label(text);
@@ -437,11 +414,11 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
    GtkWidget *hbox_temp;
    GtkWidget *hseparator;
    GtkWidget *notebook;
-   /* FIXME: Uncomment when support for Calendar and Task has been added */
+   /* FIXME: Uncomment when support for Task has been added */
 #if 0
-   GtkWidget *radio_button_datebook_version[2];
    GtkWidget *radio_button_todo_version[2];
 #endif
+   GtkWidget *radio_button_datebook_version[2];
    GtkWidget *radio_button_address_version[2];
    GtkWidget *radio_button_memo_version[3];
    long ivalue;
@@ -458,19 +435,15 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
    jp_logf(JP_LOG_DEBUG, "cb_prefs_gui\n");
    if (window) {
       jp_logf(JP_LOG_DEBUG, "pref_window is already up\n");
-#ifdef ENABLE_GTK2
       /* Shift focus to existing window if called again
          and window is still alive. */
       gtk_window_present(GTK_WINDOW(window));
-#endif
       return;
    }
 
    main_window = data;
 
    window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-   /*gtk_window_set_default_size(GTK_WINDOW(window), 500, 300); */
-
    gtk_container_set_border_width(GTK_CONTAINER(window), 10);
    g_snprintf(temp, sizeof(temp), "%s %s", PN, _("Preferences"));
    gtk_window_set_title(GTK_WINDOW(window), temp);
@@ -481,6 +454,7 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
    vbox = gtk_vbox_new(FALSE, 5);
    gtk_container_add(GTK_CONTAINER(window), vbox);
 
+   /* Boxes for each preference tax */
    vbox_locale   = gtk_vbox_new(FALSE, 0);
    vbox_settings = gtk_vbox_new(FALSE, 0);
    vbox_datebook = gtk_vbox_new(FALSE, 0);
@@ -499,7 +473,7 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
    gtk_container_set_border_width(GTK_CONTAINER(vbox_alarms), 5);
    gtk_container_set_border_width(GTK_CONTAINER(vbox_conduits), 5);
 
-   /*Add the notebook for repeat types */
+   /* Notebook for preference tabs */
    notebook = gtk_notebook_new();
    gtk_notebook_set_tab_pos(GTK_NOTEBOOK(notebook), GTK_POS_TOP);
    label = gtk_label_new(_("Locale"));
@@ -508,7 +482,7 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
    gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox_settings, label);
    label = gtk_label_new(_("Datebook"));
    gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox_datebook, label);
-   label = gtk_label_new(_("Address"));
+   label = gtk_label_new(C_("prefgui","Address"));
    gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox_address, label);
    label = gtk_label_new(_("ToDo"));
    gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox_todo, label);
@@ -524,11 +498,11 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
    /* Locale preference tab */
    table = gtk_table_new(5, 2, FALSE);
    gtk_table_set_row_spacings(GTK_TABLE(table),0);
-   gtk_table_set_col_spacings(GTK_TABLE(table),0);
+   gtk_table_set_col_spacings(GTK_TABLE(table),5);
    gtk_box_pack_start(GTK_BOX(vbox_locale), table, FALSE, FALSE, 0);
 
    /* Character Set */
-   label = gtk_label_new(_("Character Set "));
+   label = gtk_label_new(_("Character Set"));
    gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(label),
 			     0, 1, 0, 1);
    gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
@@ -541,7 +515,7 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
    gtk_option_menu_set_history(GTK_OPTION_MENU(pref_menu), ivalue);
 
    /* Shortdate */
-   label = gtk_label_new(_("Short date format "));
+   label = gtk_label_new(_("Short date format"));
    gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(label),
 			     0, 1, 1, 2);
    gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
@@ -554,7 +528,7 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
    gtk_option_menu_set_history(GTK_OPTION_MENU(pref_menu), ivalue);
 
    /* Longdate */
-   label = gtk_label_new(_("Long date format "));
+   label = gtk_label_new(_("Long date format"));
    gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(label),
 			     0, 1, 2, 3);
    gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
@@ -567,7 +541,7 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
    gtk_option_menu_set_history(GTK_OPTION_MENU(pref_menu), ivalue);
 
    /* Time */
-   label = gtk_label_new(_("Time format "));
+   label = gtk_label_new(_("Time format"));
    gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(label),
 			     0, 1, 3, 4);
    gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
@@ -579,30 +553,15 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
    get_pref(PREF_TIME, &ivalue, &cstr);
    gtk_option_menu_set_history(GTK_OPTION_MENU(pref_menu), ivalue);
 
-   /* FDOW */
-#  ifndef ENABLE_GTK2
-   label = gtk_label_new(_("The first day of the week is "));
-   gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(label),
-			     0, 1, 4, 5);
-   gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
-
-   make_pref_menu(&pref_menu, PREF_FDOW);
-   gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(pref_menu),
-			     1, 2, 4, 5);
-
-   get_pref(PREF_FDOW, &ivalue, &cstr);
-   gtk_option_menu_set_history(GTK_OPTION_MENU(pref_menu), ivalue);
-#  endif
-
    /**********************************************************************/
    /* Settings preference tab */
    table = gtk_table_new(4, 3, FALSE);
    gtk_table_set_row_spacings(GTK_TABLE(table),0);
-   gtk_table_set_col_spacings(GTK_TABLE(table),0);
+   gtk_table_set_col_spacings(GTK_TABLE(table),5);
    gtk_box_pack_start(GTK_BOX(vbox_settings), table, FALSE, FALSE, 0);
 
    /* GTK colors file */
-   label = gtk_label_new(_("My GTK colors file is "));
+   label = gtk_label_new(_("GTK color theme file"));
    gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(label),
 			     0, 2, 0, 1);
    gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
@@ -614,14 +573,13 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
    get_pref(PREF_RCFILE, &ivalue, &cstr);
    gtk_option_menu_set_history(GTK_OPTION_MENU(pref_menu), ivalue);
 
-
    /* Port */
    label = gtk_label_new(_("Serial Port"));
    gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(label),
 			     0, 1, 1, 2);
    gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
 
-   port_entry = gtk_entry_new_with_max_length(MAX_PREF_VALUE - 2);
+   port_entry = gtk_entry_new_with_max_length(MAX_PREF_LEN - 2);
    entry_set_multiline_truncate(GTK_ENTRY(port_entry), TRUE);
    gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(port_entry),
 			     2, 3, 1, 2);
@@ -639,8 +597,7 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
    gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(port_menu),
 			     1, 2, 1, 2);
 
-
-   /* Rate */
+   /* Serial Rate */
    label = gtk_label_new(_("Serial Rate"));
    gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(label),
 			     0, 2, 2, 3);
@@ -692,8 +649,6 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
    /**********************************************************************/
    /* Datebook preference tab */
 
-   /* FIXME: undef when support for Calendar has been coded */
-#if 0
    /* Radio box to choose which database to use: Datebook/Calendar */
    group = NULL;
    radio_button_datebook_version[0] = 
@@ -723,14 +678,22 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
 
    /* Separate database selection from less important options */
    hseparator = gtk_hseparator_new();
-   gtk_box_pack_start(GTK_BOX(vbox_address), hseparator, FALSE, FALSE, 3);
-#endif
+   gtk_box_pack_start(GTK_BOX(vbox_datebook), hseparator, FALSE, FALSE, 3);
 
    /* Show highlight days check box */
    add_checkbutton(_("Highlight calendar days with appointments"),
 		   PREF_DATEBOOK_HIGHLIGHT_DAYS, vbox_datebook,
 		   cb_checkbox_set_pref);
 
+   /* Highlight today on month and week view */
+   add_checkbutton(_("Annotate today in day, week, and month views"),
+ 		   PREF_DATEBOOK_HI_TODAY, vbox_datebook, cb_checkbox_set_pref);
+ 
+   /* Show number of years on anniversaries in month and week view */
+   add_checkbutton(_("Append years on anniversaries in day, week, and month views"),
+ 	           PREF_DATEBOOK_ANNI_YEARS, vbox_datebook,
+ 	           cb_checkbox_set_pref);
+
 #ifdef ENABLE_DATEBK
    /* Show use DateBk check box */
    add_checkbutton(_("Use DateBk note tags"),
@@ -741,18 +704,7 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
    gtk_box_pack_start(GTK_BOX(vbox_datebook), checkbutton, FALSE, FALSE, 0);
    gtk_widget_show(checkbutton);
 #endif
-
-    /* Highlight today on month and week view */
-    add_checkbutton(_("Annotate today in day, week, and month views"),
- 		   PREF_DATEBOOK_HI_TODAY, vbox_datebook, cb_checkbox_set_pref);
  
-    /* Show number of years on anniversaries in month and week view */
-    add_checkbutton(
- 	_("Append years on anniversaries in day, week, and month views"),
- 	PREF_DATEBOOK_ANNI_YEARS, vbox_datebook,
- 	cb_checkbox_set_pref);
- 
-
    /**********************************************************************/
    /* Address preference tab */
 
@@ -794,7 +746,7 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
    label = gtk_label_new(_("Mail Command"));
    gtk_box_pack_start(GTK_BOX(hbox_temp), label, FALSE, FALSE, 0);
 
-   mail_command_entry = gtk_entry_new_with_max_length(MAX_PREF_VALUE - 2);
+   mail_command_entry = gtk_entry_new_with_max_length(MAX_PREF_LEN - 2);
 
    get_pref(PREF_MAIL_COMMAND, &ivalue, &cstr);
    if (cstr) {
@@ -817,10 +769,10 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
    /* Radio box to choose which database to use: Todo/Task */
    group = NULL;
    radio_button_task_version[0] = 
-     gtk_radio_button_new_with_label(group, _("Use ToDo database (Palm OS < 5.2.1) "));
+     gtk_radio_button_new_with_label(group, _("Use ToDo database (Palm OS < 5.2.1)"));
    group = gtk_radio_button_group(GTK_RADIO_BUTTON(radio_button_todo_version[0]));
    radio_button_todo_version[1] = 
-     gtk_radio_button_new_with_label(group, _("Use Task database (Palm OS > 5.2) "));
+     gtk_radio_button_new_with_label(group, _("Use Task database (Palm OS > 5.2)"));
    group = gtk_radio_button_group(GTK_RADIO_BUTTON(radio_button_todo_version[1]));
    gtk_box_pack_start(GTK_BOX(vbox_todo), radio_button_todo_version[0],
 		      FALSE, FALSE, 0);
@@ -843,18 +795,18 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
 
    /* Separate database selection from less important options */
    hseparator = gtk_hseparator_new();
-   gtk_box_pack_start(GTK_BOX(vbox_address), hseparator, FALSE, FALSE, 3);
+   gtk_box_pack_start(GTK_BOX(vbox_todo), hseparator, FALSE, FALSE, 3);
 #endif
 
-   /* The hide completed check box */
+   /* hide completed check box */
    add_checkbutton(_("Hide Completed ToDos"),
 		   PREF_TODO_HIDE_COMPLETED, vbox_todo, cb_checkbox_set_pref);
 
-   /* The hide todos not yet due check box */
+   /* hide todos not yet due check box */
    add_checkbutton(_("Hide ToDos not yet due"),
 		   PREF_TODO_HIDE_NOT_DUE, vbox_todo, cb_checkbox_set_pref);
 
-   /* The record todo completion date check box */
+   /* record todo completion date check box */
    add_checkbutton(_("Record Completion Date"),
 		   PREF_TODO_COMPLETION_DATE, vbox_todo, cb_checkbox_set_pref);
 
@@ -871,7 +823,7 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
    add_checkbutton(_("Use default number of days due"),
 		   PREF_TODO_DAYS_DUE, hbox_temp, cb_checkbox_set_pref);
 
-   todo_days_due_entry = gtk_entry_new_with_max_length(MAX_PREF_VALUE - 2);
+   todo_days_due_entry = gtk_entry_new_with_max_length(MAX_PREF_LEN - 2);
    entry_set_multiline_truncate(GTK_ENTRY(todo_days_due_entry), TRUE);
    get_pref(PREF_TODO_DAYS_TILL_DUE, &ivalue, &cstr);
    temp[0]='\0';
@@ -887,7 +839,7 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
 
    /**********************************************************************/
    /* Memo preference tab */
-   /* Radio box to choose which database to use: Memo/Memo32/Memos*/
+   /* Radio box to choose which database to use: Memo/Memos/Memo32 */
    group = NULL;
    radio_button_memo_version[0] = 
      gtk_radio_button_new_with_label(group, _("Use Memo database (Palm OS < 5.2.1)"));
@@ -915,17 +867,10 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
 		      GTK_SIGNAL_FUNC(cb_radio_set_pref),
 		      GINT_TO_POINTER((PREF_MEMO_VERSION<<16)|2));
 
-   /* Backwards compatability with MEMO32 preference */
-   /* FIXME: Would be nice to eliminate all MEMO32 references in
-    * the code and just use PREF_MEMO_VERSION everywhere */
-   get_pref(PREF_MEMO32_MODE, &ivalue, NULL);
-   if (ivalue) {
-      set_pref(PREF_MEMO_VERSION, 2, NULL, TRUE);
-   }
-
    get_pref(PREF_MEMO_VERSION, &ivalue, NULL);
    switch (ivalue) {
     case 0:
+    default:
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_button_memo_version[0]), TRUE);
       break;
     case 1:
@@ -934,35 +879,32 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
     case 2:
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_button_memo_version[2]), TRUE);
       break;
-    default:
-      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_button_memo_version[0]), TRUE);
-      break;
    }
 
    /**********************************************************************/
    /* Alarms preference tab */
 
-   /* Show open alarm windows check box */
+   /* Open alarm windows check box */
    add_checkbutton(_("Open alarm windows for appointment reminders"),
 		   PREF_OPEN_ALARM_WINDOWS, vbox_alarms, cb_checkbox_set_pref);
 
-   /* Show open alarm windows check box */
+   /* Execute alarm command check box */
    add_checkbutton(_("Execute this command"),
 		   PREF_DO_ALARM_COMMAND, vbox_alarms, cb_checkbox_set_pref);
 
-   /* Shell warning */
+   /* Shell warning label */
    label = gtk_label_new(_("WARNING: executing arbitrary shell commands can be dangerous!!!"));
    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.0);
    gtk_box_pack_start(GTK_BOX(vbox_alarms), label, FALSE, FALSE, 0);
 
-   /* Alarm Command */
+   /* Alarm Command to execute */
    hbox_temp = gtk_hbox_new(FALSE, 0);
    gtk_box_pack_start(GTK_BOX(vbox_alarms), hbox_temp, FALSE, FALSE, 0);
 
    label = gtk_label_new(_("Alarm Command"));
    gtk_box_pack_start(GTK_BOX(hbox_temp), label, FALSE, FALSE, 10);
 
-   alarm_command_entry = gtk_entry_new_with_max_length(MAX_PREF_VALUE - 2);
+   alarm_command_entry = gtk_entry_new_with_max_length(MAX_PREF_LEN - 2);
    get_pref(PREF_ALARM_COMMAND, &ivalue, &cstr);
    if (cstr) {
       gtk_entry_set_text(GTK_ENTRY(alarm_command_entry), cstr);
@@ -990,10 +932,12 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
    gtk_box_pack_start(GTK_BOX(vbox_alarms), label, FALSE, FALSE, 0);
 #else
    label = gtk_label_new(_("%D (description substitution) is disabled in this build"));
+   gtk_widget_set_sensitive(label, FALSE);
    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
    gtk_box_pack_start(GTK_BOX(vbox_alarms), label, FALSE, FALSE, 0);
 
    label = gtk_label_new(_("%N (note substitution) is disabled in this build"));
+   gtk_widget_set_sensitive(label, FALSE);
    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
    gtk_box_pack_start(GTK_BOX(vbox_alarms), label, FALSE, FALSE, 0);
 #endif
@@ -1001,31 +945,24 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
    /**********************************************************************/
    /* Conduits preference tab */
 
-   /* Show sync datebook check box */
+   /* Sync datebook check box */
    add_checkbutton(_("Sync datebook"),
 		   PREF_SYNC_DATEBOOK, vbox_conduits, cb_checkbox_set_pref);
 
-   /* Show sync address check box */
+   /* Sync address check box */
    add_checkbutton(_("Sync address"),
 		   PREF_SYNC_ADDRESS, vbox_conduits, cb_checkbox_set_pref);
 
-   /* Show sync todo check box */
+   /* Sync todo check box */
    add_checkbutton(_("Sync todo"),
 		   PREF_SYNC_TODO, vbox_conduits, cb_checkbox_set_pref);
 
-   /* FIXME: Eliminate SYNC_MEMO32 everywhere in the code in favor of
-    * SYNC_MEMO.  This stanza ensures backward compatability */
-   get_pref(PREF_SYNC_MEMO32, &ivalue, NULL);
-   if (ivalue) {
-      set_pref(PREF_SYNC_MEMO, 1, NULL, TRUE);
-   }
-
-   /* Show sync memo check box */
+   /* Sync memo check box */
    add_checkbutton(_("Sync memo"),
 		   PREF_SYNC_MEMO, vbox_conduits, cb_checkbox_set_pref);
 
 #ifdef ENABLE_MANANA
-   /* Show sync Ma~nana check box */
+   /* Show sync Manana check box */
    add_checkbutton(_("Sync Manana"),
 		   PREF_SYNC_MANANA, vbox_conduits, cb_checkbox_set_pref);
 #endif
@@ -1044,7 +981,7 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
       for (temp_list = plugin_list; temp_list; temp_list = temp_list->next) {
 	 Pplugin = (struct plugin_s *)temp_list->data;
 	 if (Pplugin) {
-	    /* Make a checkbox for each plugin */
+	    /* Make a Sync checkbox for each plugin */
 	    g_snprintf(temp, sizeof(temp), _("Sync %s (%s)"), Pplugin->name, Pplugin->full_path);
 	    checkbutton = gtk_check_button_new_with_label(temp);
 	    gtk_box_pack_start(GTK_BOX(vbox_conduits), checkbutton, FALSE, FALSE, 0);
@@ -1061,19 +998,16 @@ void cb_prefs_gui(GtkWidget *widget, gpointer data)
 
 #endif
 
-   /* Create a "Done" button */
+   /* Done button */
    hbox_temp = gtk_hbutton_box_new();
    gtk_button_box_set_layout(GTK_BUTTON_BOX (hbox_temp), GTK_BUTTONBOX_END);
    gtk_box_pack_start(GTK_BOX(vbox), hbox_temp, FALSE, FALSE, 1);
 
-#ifdef ENABLE_GTK2
    button = gtk_button_new_from_stock(GTK_STOCK_OK);
-#else
-   button = gtk_button_new_with_label(_("Done"));
-#endif
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_quit), window);
    gtk_box_pack_end(GTK_BOX(hbox_temp), button, FALSE, FALSE, 0);
 
    gtk_widget_show_all(window);
 }
+
