@@ -1,4 +1,4 @@
-/* $Id: print.c,v 1.42 2008/06/19 04:12:07 rikster5 Exp $ */
+/* $Id: print.c,v 1.45 2009-09-19 20:57:27 rikster5 Exp $ */
 
 /*******************************************************************************
  * print.c
@@ -54,7 +54,7 @@
 /******************************* Global vars **********************************/
 static FILE *out;
 static int first_hour, first_min, last_hour, last_min;
-extern int datebook_category;
+extern int datebk_category;
 int fill_in(struct tm *date, AppointmentList *a_list);
 void ps_strncat(char *dest, char *src, int n);
 
@@ -69,7 +69,7 @@ char *PaperSizes[] = { "Letter", "Legal", "Statement", "Tabloid", "Ledger",
                        "Filo" };
 
 /****************************** Main Code *************************************/
-FILE *print_open()
+FILE *print_open(void)
 {
    const char *command;
 
@@ -86,14 +86,14 @@ void print_close(FILE *f)
    pclose(f);
 }
 
-int courier_12()
+int courier_12(void)
 {
    /* fprintf(out, "/Courier 12 selectfont\n"); */
    fprintf(out, "%cC12\n", FLAG_CHAR);
    return EXIT_SUCCESS;
 }
 
-int courier_bold_12()
+int courier_bold_12(void)
 {
    /* fprintf(out, "/Courier-Bold 12 selectfont\n"); */
    fprintf(out, "%cCB12\n", FLAG_CHAR);
@@ -121,7 +121,7 @@ int puttext(float x, float y, char *text)
    return EXIT_SUCCESS;
 }
 
-int header()
+int header(void)
 {
    time_t ltime;
 
@@ -290,6 +290,8 @@ int fill_in(struct tm *date, AppointmentList *a_list)
 	    strcat(str, " ");
 	    strncat(str, temp_al->mappt.appt.description, sizeof(str)-strlen(str)-2);
 	    str[128]='\0';
+            /* FIXME: Add location in parentheses (loc) as the Palm does.
+             * We would need to check strlen, etc., before adding */
 	 }
 	 if (y > 1.0) {
 	    puttext(x, y, str);
@@ -513,7 +515,7 @@ int print_months_appts(struct tm *date_in, PaperSize paper_size)
 	    ret = db3_parse_tag(temp_al->mappt.appt.note, &db3_type, &db4);
 	    /* jp_logf(JP_LOG_DEBUG, "category = 0x%x\n", db4.category); */
 	    cat_bit=1<<db4.category;
-	    if (!(cat_bit & datebook_category)) {
+	    if (!(cat_bit & datebk_category)) {
 	       jp_logf(JP_LOG_DEBUG, "skipping rec not in this category\n");
 	       continue;
 	    }
@@ -534,6 +536,8 @@ int print_months_appts(struct tm *date_in, PaperSize paper_size)
 	    if (temp_al->mappt.appt.description) {
 	       ps_strncat(desc, temp_al->mappt.appt.description, 100);
 	       desc[sizeof(desc)-1]='\0';
+               /* FIXME: Add location in parentheses (loc) as the Palm does.
+                * We would need to check strlen, etc., before adding */
 	    }
 	    remove_cr_lfs(desc);
 	    fprintf(out, "%s (%s) %simedItem\n", tmp, desc,
@@ -693,7 +697,7 @@ int print_weeks_appts(struct tm *date_in, PaperSize paper_size)
 	 if (use_db3_tags) {
 	    ret = db3_parse_tag(temp_al->mappt.appt.note, &db3_type, &db4);
 	    cat_bit=1<<db4.category;
-	    if (!(cat_bit & datebook_category)) continue;
+	    if (!(cat_bit & datebk_category)) continue;
 	 }
 #endif
 	 if (isApptOnDate(&(temp_al->mappt.appt), &date))
@@ -741,7 +745,7 @@ int print_weeks_appts(struct tm *date_in, PaperSize paper_size)
 	    ret = db3_parse_tag(temp_al->mappt.appt.note, &db3_type, &db4);
 	    jp_logf(JP_LOG_DEBUG, "category = 0x%x\n", db4.category);
 	    cat_bit=1<<db4.category;
-	    if (!(cat_bit & datebook_category)) {
+	    if (!(cat_bit & datebk_category)) {
 	       jp_logf(JP_LOG_DEBUG, "skip rec not in this category\n");
 	       continue;
 	    }
@@ -770,6 +774,8 @@ int print_weeks_appts(struct tm *date_in, PaperSize paper_size)
 	      }
 	    if (temp_al->mappt.appt.description) {
 	       ps_strncat(desc, temp_al->mappt.appt.description, 250);
+               /* FIXME: Add location in parentheses (loc) as the Palm does.
+                * We would need to check strlen, etc., before adding */
 	       remove_cr_lfs(desc);
 	    }
 	    fprintf(out, "%s (%s) itemline\n", short_date, desc);
@@ -791,7 +797,7 @@ int print_weeks_appts(struct tm *date_in, PaperSize paper_size)
  * Address code
  */
 
-int print_address_header()
+int print_address_header(void)
 {
    time_t ltime;
    struct tm *date;
