@@ -1,4 +1,7 @@
-/* todo.h
+/* $Id: todo.h,v 1.13 2009-11-08 17:12:10 rousseau Exp $ */
+
+/*******************************************************************************
+ * todo.h
  * A module of J-Pilot http://jpilot.org
  * 
  * Copyright (C) 1999-2002 by Judd Montgomery
@@ -15,7 +18,8 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+ ******************************************************************************/
+
 #ifndef __TODO_H__
 #define __TODO_H__
 
@@ -39,12 +43,12 @@ int get_todos2(ToDoList **todo_list, int sort_order,
 int get_todo_app_info(struct ToDoAppInfo *ai);
 int pc_todo_write(struct ToDo *todo, PCRecType rt, unsigned char attrib,
 		  unsigned int *unique_id);
-int todo_print();
+int todo_print(void);
 int todo_import(GtkWidget *window);
 int todo_export(GtkWidget *window);
 
 /* I only export this for datebook, don't use this */
 void todo_update_clist(GtkWidget *clist, GtkWidget *tooltip_widget,
-		       ToDoList *todo_list, int category, int main);
+		       ToDoList **todo_list, int category, int main);
 
 #endif
