@@ -1,4 +1,4 @@
-/* $Id: utils.c,v 1.168 2009/01/22 16:59:30 rikster5 Exp $ */
+/* $Id: utils.c,v 1.178 2009/09/10 06:01:55 rikster5 Exp $ */
 
 /*******************************************************************************
  * utils.c
@@ -529,7 +529,7 @@ char *charset_p2newj(const char *buf, int max_len, int char_set)
 /* This function will copy an empty DB file 
  * from the share directory to the users JPILOT_HOME directory
  * if it doesn't exist already and its length is > 0 */
-int check_copy_DBs_to_home()
+int check_copy_DBs_to_home(void)
 {
    FILE *in, *out;
    struct stat sbuf;
@@ -544,6 +544,7 @@ int check_copy_DBs_to_home()
       "ContactsDB-PAdd.pdb",
       "ToDoDB.pdb",
       "TasksDB-PTod.pdb",
+      "MaanaDB.pdb",
       "MemoDB.pdb",
       "MemosDB-PMem.pdb",
       "Memo32DB.pdb",
@@ -588,7 +589,7 @@ int check_copy_DBs_to_home()
    return EXIT_SUCCESS;
 }
 
-int check_hidden_dir()
+int check_hidden_dir(void)
 {
    struct stat statb;
    char hidden_dir[FILENAME_MAX];
@@ -781,7 +782,7 @@ int cleanup_pc_file(char *DB_name, unsigned int *max_id)
 }
 
 /* Compact all pc3 files including plugins */
-int cleanup_pc_files()
+int cleanup_pc_files(void)
 {
    int ret;
    int fail_flag;
@@ -920,6 +921,7 @@ int delete_pc_record(AppType app_type, void *VP, int flag)
    long ivalue;
 #endif
    long memo_version;
+   long datebook_version;
    long char_set;
 
    jp_logf(JP_LOG_DEBUG, "delete_pc_record(%d, %d)\n", app_type, flag);
@@ -942,7 +944,12 @@ int delete_pc_record(AppType app_type, void *VP, int flag)
       record_type = mappt->rt;
       unique_id = mappt->unique_id;
       attrib = mappt->attrib;
-      strcpy(filename, "DatebookDB.pc3");
+      get_pref(PREF_DATEBOOK_VERSION, &datebook_version, NULL);
+      if (datebook_version) {
+	 strcpy(filename, "CalendarDB-PDat.pc3");
+      } else {
+         strcpy(filename, "DatebookDB.pc3");
+      }
       break;
     case ADDRESS:
       maddr = (MyAddress *) VP;
@@ -1066,13 +1073,7 @@ int delete_pc_record(AppType app_type, void *VP, int flag)
       switch (app_type) {
        case DATEBOOK:
 	 appt=&mappt->appt;
-         /* %RW Conversion doesn't appear necessary. */
-	 if (char_set != CHAR_SET_LATIN1) {
-	    if (appt->description) charset_j2p(appt->description, strlen(appt->description)+1, char_set);
-	    if (appt->note) charset_j2p(appt->note, strlen(appt->note)+1, char_set);
-	 }
-
-	 if (pack_Appointment(appt, RecordBuffer, datebook_v1) == -1) {
+	 if (jp_pack_Appointment(appt, RecordBuffer, datebook_v1) == -1) {
 	    PRINT_FILE_LINE;
 	    jp_logf(JP_LOG_WARN, "pack_Appointment %s\n", _("error"));
 	 }
@@ -1815,7 +1816,7 @@ int forward_backward_in_appt_time(const struct Appointment *appt,
 /* Displays usage string on supplied file handle */
 void fprint_usage_string(FILE *out)
 {
-   fprintf(out, "%s [ -v || -h || [-d] [-p] [-a || -A] [-i] [-geometry] ]\nn", EPN);
+   fprintf(out, "%s [ -v || -h || [-d] [-p] [-a || -A] [-i] [-geometry] ]\n", EPN);
    fprintf(out, "%s", _(" -v displays version and compile options and exits.\n"));
    fprintf(out, "%s", _(" -h displays help and exits.\n"));
    fprintf(out, "%s", _(" -d displays debug info to stdout.\n"));
@@ -2108,149 +2109,8 @@ int get_pixmaps(GtkWidget *widget,
 		GdkPixmap **out_pixmap,
 		GdkBitmap **out_mask)
 {
-/* Note pixmap */
-char * xpm_note[] = {
-   "11 16 3 1",
-   "       c None",
-   ".      c #000000000000",
-   "X      c #cccccccccccc",
-   "           ",
-   " ......    ",
-   " .XXX.X.   ",
-   " .XXX.XX.  ",
-   " .XXX.XXX. ",
-   " .XXX..... ",
-   " .XXXXXXX. ",
-   " .XXXXXXX. ",
-   " .XXXXXXX. ",
-   " .XXXXXXX. ",
-   " .XXXXXXX. ",
-   " .XXXXXXX. ",
-   " .XXXXXXX. ",
-   " ......... ",
-   "           ",
-   "           "
-};
-
-/* Alarm pixmap */
-char * xpm_alarm[] = {
-   "16 16 3 1",
-   "       c None",
-   ".      c #000000000000",
-   "X      c #cccccccccccc",
-   "                ",
-   "   .       .    ",
-   "  ...     ...   ",
-   "  ...........   ",
-   "   .XXXXXXXX.   ",
-   "  .XXXX.XXXXX.  ",
-   " .XXXXX.XXXXXX. ",
-   " .X.....XXXXXX. ",
-   " .XXXXXXXXXXX.  ",
-   "  .XXXXXXXXX.   ",
-   "   .XXXXXXX.    ",
-   "   .........    ",
-   "   .       .    ",
-   " ....     ....  ",
-   "                ",
-   "                "
-};
-
-char * xpm_check[] = {
-   "12 16 3 1",
-   "       c None",
-   ".      c #000000000000",
-   "X      c #cccccccccccc",
-   "                ",
-   " .........  ",
-   " .XXXXXXX.  ",
-   " .X     X.  ",
-   " .X     X.  ",
-   " .X     X.  ",
-   " .X     X.  ",
-   " .X     X.  ",
-   " .X     X.  ",
-   " .X     X.  ",
-   " .X     X.  ",
-   " .X     X.  ",
-   " .XXXXXXX.  ",
-   " .........  ",
-   "            ",
-   "            "
-};
-
-char * xpm_checked[] = {
-   "12 16 4 1",
-   "       c None",
-   ".      c #000000000000",
-   "X      c #cccccccccccc",
-   "R      c #FFFF00000000",
-   "            ",
-   " .........  ",
-   " .XXXXXXX.RR",
-   " .X     XRR ",
-   " .X     RR  ",
-   " .X    RR.  ",
-   " .X    RR.  ",
-   " .X   RRX.  ",
-   " RR  RR X.  ",
-   " .RR RR X.  ",
-   " .X RR  X.  ",
-   " .X  R  X.  ",
-   " .XXXXXXX.  ",
-   " .........  ",
-   "            ",
-   "            "
-};
-
-char * xpm_float_check[] = {
-   "14 16 4 1",
-   "       c None",
-   ".      c #000000000000",
-   "X      c #CCCCCCCCCCCC",
-   "W      c #FFFFFFFFFFFF",
-   "              ",
-   "     ....     ",
-   "    ......    ",
-   "   ..XXXX..   ",
-   "  ..XWWWWX..  ",
-   " ..XWWWWWWX.. ",
-   " ..XWWWWWWX.. ",
-   " ..XWWWWWWX.. ",
-   " ..XWWWWWWX.. ",
-   " ..XWWWWWWX.. ",
-   "  ..XWWWWX..  ",
-   "   ..XXXX..   ",
-   "    ......    ",
-   "     ....     ",
-   "              ",
-   "              "
-};
-
-char * xpm_float_checked[] = {
-   "14 16 5 1",
-   "       c None",
-   ".      c #000000000000",
-   "X      c #cccccccccccc",
-   "R      c #FFFF00000000",
-   "W      c #FFFFFFFFFFFF",
-   "              ",
-   "     ....     ",
-   "    ...... RR ",
-   "   ..XXXX.RR  ",
-   "  ..XWWWWRR.  ",
-   " ..XWWWWRRX.. ",
-   " ..XWWWWRRX.. ",
-   " ..XWWWRRWX.. ",
-   " .RRWWRRWWX.. ",
-   " ..RRWRRWWX.. ",
-   "  ..XRRWWX..  ",
-   "   ..XRXX..   ",
-   "    ......    ",
-   "     ....     ",
-   "              ",
-   "              "
-};
+   /* Externally stored icon definitions */
+   #include "icons/clist_mini_icons.h"
 
    static int inited=0;
    static GdkPixmap *pixmap_note;
@@ -2267,47 +2127,48 @@ char * xpm_float_checked[] = {
    static GdkBitmap *mask_float_checked;
    GtkStyle *style;
 
-   if (inited) {
-      goto assign;
-   }
+   /* Pixmaps are created only once when procedure is first called */
+   if (!inited) {
 
-   inited=1;
+      inited=1;
 
-   /* Make the note pixmap */
-   /* style = gtk_widget_get_style(window); */
-   style = gtk_widget_get_style(widget);
-   pixmap_note = gdk_pixmap_create_from_xpm_d(widget->window,  &mask_note,
-					      &style->bg[GTK_STATE_NORMAL],
-					      (gchar **)xpm_note);
+      /* Make the note pixmap */
+      /* style = gtk_widget_get_style(window); */
+      style = gtk_widget_get_style(widget);
+      pixmap_note = gdk_pixmap_create_from_xpm_d(widget->window, &mask_note,
+                                                 &style->bg[GTK_STATE_NORMAL],
+                                                 (gchar **)xpm_note);
 
-   /* Make the alarm pixmap */
-   pixmap_alarm = gdk_pixmap_create_from_xpm_d(widget->window,  &mask_alarm,
-					       &style->bg[GTK_STATE_NORMAL],
-					       (gchar **)xpm_alarm);
+      /* Make the alarm pixmap */
+      pixmap_alarm = gdk_pixmap_create_from_xpm_d(widget->window, &mask_alarm,
+                                                  &style->bg[GTK_STATE_NORMAL],
+                                                  (gchar **)xpm_alarm);
 
-   /* Make the check pixmap */
-   pixmap_check = gdk_pixmap_create_from_xpm_d(widget->window,  &mask_check,
-					       &style->bg[GTK_STATE_NORMAL],
-					       (gchar **)xpm_check);
+      /* Make the check pixmap */
+      pixmap_check = gdk_pixmap_create_from_xpm_d(widget->window, &mask_check,
+                                                  &style->bg[GTK_STATE_NORMAL],
+                                                  (gchar **)xpm_check);
 
-   /* Make the checked pixmap */
-   pixmap_checked = gdk_pixmap_create_from_xpm_d(widget->window,  &mask_checked,
-					       &style->bg[GTK_STATE_NORMAL],
-					       (gchar **)xpm_checked);
+      /* Make the checked pixmap */
+      pixmap_checked = gdk_pixmap_create_from_xpm_d
+                         (widget->window, &mask_checked,
+                          &style->bg[GTK_STATE_NORMAL],
+                          (gchar **)xpm_checked);
 
-   /* Make the float_checked pixmap */
-   pixmap_float_check = gdk_pixmap_create_from_xpm_d
-     (widget->window,  &mask_float_check,
-      &style->bg[GTK_STATE_NORMAL],
-      (gchar **)xpm_float_check);
+      /* Make the float_checked pixmap */
+      pixmap_float_check = gdk_pixmap_create_from_xpm_d
+                             (widget->window, &mask_float_check,
+                              &style->bg[GTK_STATE_NORMAL],
+                              (gchar **)xpm_float_check);
 
-   /* Make the float_checked pixmap */
-   pixmap_float_checked = gdk_pixmap_create_from_xpm_d
-     (widget->window,  &mask_float_checked,
-      &style->bg[GTK_STATE_NORMAL],
-      (gchar **)xpm_float_checked);
+      /* Make the float_checked pixmap */
+      pixmap_float_checked = gdk_pixmap_create_from_xpm_d
+                               (widget->window, &mask_float_checked,
+                                &style->bg[GTK_STATE_NORMAL],
+                                (gchar **)xpm_float_checked);
+
+   }   /* End initialization of pixmaps */
 
-   assign:
    switch (which_one) {
     case PIXMAP_NOTE:
       *out_pixmap = pixmap_note;
@@ -2341,7 +2202,7 @@ char * xpm_float_checked[] = {
    return EXIT_SUCCESS;
 }
 
-int get_timeout_interval()
+int get_timeout_interval(void)
 {
    const char *svalue;
 
@@ -2381,6 +2242,14 @@ void jp_charset_p2j(char *const buf, int max_len)
 
 }
 
+char* jp_charset_p2newj(const char *buf, int max_len)
+{
+   long char_set;
+
+   get_pref(PREF_CHAR_SET, &char_set, NULL);
+   return(charset_p2newj(buf, max_len, char_set));
+}
+
 int jp_close_home_file(FILE *pc_in)
 {
    /* unlock access */
@@ -2831,7 +2700,7 @@ int pdb_file_modify_record(char *DB_name, void *record_in, int size_in,
    int found;
    pi_uid_t uid;
 
-   jp_logf(JP_LOG_DEBUG, "pi_file_modify_record\n");
+   jp_logf(JP_LOG_DEBUG, "pdb_file_modify_record\n");
 
    g_snprintf(local_pdb_file, sizeof(local_pdb_file), "%s.pdb", DB_name);
    get_home_file_name(local_pdb_file, full_local_pdb_file, sizeof(full_local_pdb_file));
@@ -2936,6 +2805,8 @@ int pdb_file_write_app_block(char *DB_name, void *bufp, size_t size_in)
    int attr;
    int cat;
    pi_uid_t uid;
+   struct stat statb;
+   struct utimbuf times;
 
    jp_logf(JP_LOG_DEBUG, "pdb_file_write_app_block\n");
 
@@ -2944,6 +2815,12 @@ int pdb_file_write_app_block(char *DB_name, void *bufp, size_t size_in)
    strcpy(full_local_pdb_file2, full_local_pdb_file);
    strcat(full_local_pdb_file2, "2");
 
+   /* After we are finished, set the create and modify times of new file
+      to the same as the old */
+   stat(full_local_pdb_file, &statb);
+   times.actime = statb.st_atime;
+   times.modtime = statb.st_mtime;
+
    pf1 = pi_file_open(full_local_pdb_file);
    if (!pf1) {
       jp_logf(JP_LOG_WARN, _("Unable to open file: %s\n"), full_local_pdb_file);
@@ -2975,6 +2852,8 @@ int pdb_file_write_app_block(char *DB_name, void *bufp, size_t size_in)
       jp_logf(JP_LOG_WARN, "pdb_file_write_app_block(): %s\n", _("rename failed"));
    }
 
+   utime(full_local_pdb_file, &times);
+
    return EXIT_SUCCESS;
 }
 
@@ -3058,7 +2937,7 @@ void print_string(char *str, int len)
    jp_logf(JP_LOG_STDOUT, "\n");
 }
 
-int read_gtkrc_file()
+int read_gtkrc_file(void)
 {
    char filename[FILENAME_MAX];
    char fullname[FILENAME_MAX];
@@ -3125,7 +3004,7 @@ void rename_dbnames(char dbname[][32])
 	    strcpy(dbname[i], "CalendarDB-PDat.pc3");
 	 }
 	 if (!strcmp(dbname[i], "DatebookDB")) {
-	    strcpy(dbname[i], "CalendarDB-Pdat");
+	    strcpy(dbname[i], "CalendarDB-PDat");
 	 }
       }
 
