@@ -1,4 +1,4 @@
-/* $Id: weekview_gui.c,v 1.43 2008/06/19 04:12:08 rikster5 Exp $ */
+/* $Id: weekview_gui.c,v 1.47 2009-09-19 20:57:27 rikster5 Exp $ */
 
 /*******************************************************************************
  * weekview_gui.c
@@ -25,7 +25,8 @@
 #include <stdlib.h>
 #include <string.h>
 #include <gtk/gtk.h>
-#include <pi-datebook.h>
+
+#include "jp-pi-calendar.h"
 
 #include "i18n.h"
 #include "utils.h"
@@ -35,7 +36,7 @@
 #include "print.h"
 
 /******************************* Global vars **********************************/
-extern int datebook_category;
+extern int datebk_category;
 extern int glob_app;
 
 GtkWidget *weekview_window=NULL;
@@ -82,7 +83,7 @@ static void cb_week_print(GtkWidget *widget, gpointer data)
    }
 }
 
-void freeze_weeks_appts()
+void freeze_weeks_appts(void)
 {
    int i;
 
@@ -91,7 +92,7 @@ void freeze_weeks_appts()
    }
 }
 
-void thaw_weeks_appts()
+void thaw_weeks_appts(void)
 {
    int i;
 
@@ -208,7 +209,7 @@ int display_weeks_appts(struct tm *date_in, GtkWidget **day_texts)
 	    ret = db3_parse_tag(temp_al->mappt.appt.note, &db3_type, &db4);
 	    jp_logf(JP_LOG_DEBUG, "category = 0x%x\n", db4.category);
 	    cat_bit=1<<db4.category;
-	    if (!(cat_bit & datebook_category)) {
+	    if (!(cat_bit & datebk_category)) {
 	       jp_logf(JP_LOG_DEBUG, "skipping rec not in this category\n");
 	       continue;
 	    }
@@ -224,8 +225,11 @@ int display_weeks_appts(struct tm *date_in, GtkWidget **day_texts)
 	    }
 	    if (temp_al->mappt.appt.description) {
 	       strncat(desc, temp_al->mappt.appt.description, 70);
+               /* FIXME: This kind of truncation is bad for UTF-8 */
 	       desc[62]='\0';
 	    }
+            /* FIXME: Add location in parentheses (loc) as the Palm does.
+             * We would need to check strlen, etc., before adding */
 	    remove_cr_lfs(desc);
 
 	    /* Append number of anniversary years if enabled & appropriate */
